(CNN) -- World War I began a hundred years ago this summer, but for many of us it might as well be a thousand. We know it, if we know it at all, as a dimly remembered chapter in high school history, or as scenes from old black-and-white movies of soldiers hunkered in trenches doing battle with Germans in pointy helmets. It was all too real for more than 65 million men from some 30 nations who were plunged into carnage the likes of which the world had never before seen.

Every one of those soldiers is dead, and the causes they fought for are lost on many of us. Yet this "war to end all wars" is not a remote event. In fact, World War I changed the world forever, and its effects are all around us.

To begin with, it rewrote history at the grandest level: Empires fell, and new nations--Austria, Hungary, Yugoslavia and Poland among them-- were born in the ashes. Leaders of the still-powerful French and British empires used the conflict to redraw borders in ways that set the stage for future conflicts that stretch on today, in the Middle East, for example.

But there is much more. The first mass conflict among industrialized nations, World War I upended the way war was fought. The weapons it introduced -- submarines, machine guns, poison gas, grenades, tanks -- are all still part of our arsenals. And it was World War I that made airpower and strategic bombing central to the success of any future war. Trench warfare traumatized both soldiers and landscapes, and informed art and literature for years. It would reappear as a battlefield strategy in both the Korean War and in the Iran-Iraq War of the 1980s.

At home and on the battlefield, World War I put new objects and words into circulation: "cooties" are something no kid wants to get, but for GIs in the trenches, they were real and they were lice; and sanitary napkins developed from the handy alternative use nurses found for cellulose bandage material produced for the war. The war popularized Kleenex and tea bags and zippers.

In fact, every time you admire an aircraft carrier, eat a meatless sausage, sit under a sun lamp, wear a Burberry trench coat, or set your clock ahead for daylight saving time, you are reaching back to commune with World War I.

The dawn of chemical weapons

World War I's new weapons caused previously unseen and horrific kinds of injuries, and scientists raced to develop protections against them -- or to make even more lethal versions to use against the enemy. Poison gas was first used on a mass scale by the Germans in April 1915 during the second battle of Ypres, and cloths strapped over the mouth and nose were at first the only protection.

Gas masks evolved quickly, though, and by the end of the war even some horses and dogs at the front had their own. The horrors of gas attacks resonate today in the reports of chemical weapons use in Syria, and, earlier, in Saddam Hussein's Iraq, and the world still struggles to contain them.

All told, more than 9 million died in the conflict, and 21 million were wounded, psychologically scarring a generation. Soldiers were at pains to explain this new human experience of battle to those back home.

The English poet Siegfried Sassoon had this to say in 1917 about his time at the front: "I'm back from hell/With loathsome thoughts to sell/Secrets of death to tell;/ And horrors from the abyss." Many others had no more words: these victims of "war exhaustion," (the label of shell shock became more common) had trouble speaking: they are the forefathers of veterans with post-traumatic stress disorder today.

Likewise the scale and type of physical injuries challenged the ingenuity of prosthesis designers, whose work to replace lost body parts would enable countless soldiers to return to productive civilian life, a process echoed today as soldiers from recent wars recover from the toll of roadside bombs.

World War I also set the stage for future conflicts, by breaking down barriers between military and civilian life. While soldiers fought at the battlefront, civilian women and men built their weapons, distributed food and propaganda, and kept the home front running. Women gained new visibility in society, moving into the jobs vacated by enlisted men.

They drove streetcars, smelted iron, built bombs and then, after a long day at the factory, scrounged for food for their families. Civilians working for the war effort meant that anyone could be a target: German Fokker planes attacked at the front, but Zeppelin airships bombed London and Paris. "Total war" made the home front a dangerous place.

This war left few things unchanged in its path, even in lands that saw no fighting. Although it was mainly fought in Europe, it awakened many to the scope and diversity of the planet. "The entire world is participating in the war!" a French almanac exclaimed in 1917, showing its readers a map of the world divided into enemy, ally, and neutral peoples. Whether as laborers or soldiers, Europeans went to other countries, and millions of Americans, Africans and Asians came to Europe.

'Trapped in a net of woe'

More than two million United States soldiers fought in Europe, and the British and French empires brought over their colonial subjects. "We perish in the desert; you wash yourself and lie in bed," wrote an Indian soldier to his wife in September 1915. "We are trapped in a net of woe; while you go free. Our life is a living death."

How did Europe arrive at this state of catastrophe? The assassination of Austrian-Hungarian Archduke Franz Ferdinand and his wife, Sophie, on June 28, 1914 by the Bosnian Serb Gavrilo Princip caused an international crisis that led in just over a month to multiple mobilizations.

The Archduke, traveling in an open car, was in Sarajevo to inspect imperial armed forces in Bosnia and Herzegovina, which were among the former Ottoman territories annexed by Austria-Hungary in 1908, angering Serbian nationalists such as Princip.

After the assassination, Austria-Hungary gave Serbia an ultimatum, causing Russia to intervene to protect its Serbian client state, and Germany to help its Austrian ally. And so it all began: the military obligations imposed by the system of alliances drew one power after another into combat.

All parties thought the war would be a short one; none imagined the speed with which the conflict would degenerate into a series of local atrocities (the Belgians became the conflict's first group of refugees, as they fled German rape and plunder) and mass slaughter across many fronts.

The habituation to violence and the acceptance of these lethal new inventions is one of World War I's most unfortunate legacies. Chemical weapons provides a case in point. Their effectiveness, as proved by the precedent of World War I, has given them a permanent place in many state arsenals, despite the paper trail of international agreements meant to ban their use. Democracies and dictatorships (France and Italy) both used them in the interwar period as agents of colonial conquest and rule, and Syria is the most recent example of their use.

As we approach this 100-year anniversary, each combatant country is remembering the war in its own way. In America, the echo has been fainter, due as much to the country's late entry into the war (April 1917) as to the prominence of World War II.

"The First World War is not well understood or remembered in the United States, U.S. Defense Secretary Robert Gates said at a 2008 Veterans Day ceremony at which the last living American combatant, Frank Buckles, who died in 2011, was present. "Yet few events have so markedly shaped the world we live in."

At war's end in 1918, America emerged from its 18 months of combat with a raft of new legislation that is still in force -- such as the Selective Service Act, which still today allows the President to draft soldiers, and the Espionage Act, used recently to charge Chelsea Manning and Edward Snowden -- and with a new status as an international power.

A century of debates over how and whether America should intervene in global crises would lie ahead.

@highlight

Ruth Ben-Ghiat: 100 years ago this summer, World War I began. Its legacies still resonate

@highlight

She says its carnage was unprecedented; it changed military, sparked innovations

@highlight

She says empires fell, borders shifted, new words emerged, and women's roles changed

@highlight

Ben-Ghiat: Begun after an assassination, it would draw in 30 nations, upending the world