If you want to know where American food traditions are headed, look back. Many of today's most healthful eating trends bear a strong resemblance to yesterday's: Nearby farms offering nutritious, peak-of-season produce; slow-cooked dinners that foster leisurely family meals; an emphasis on meatless dishes and minimally processed foods.

Sales of organic food have risen more than 20 percent per year since the 1990s, the USDA says.

"It used to be that packaging and convenience were all the rage. But today, food lovers also want to know where their food comes from and how to prepare it in the simplest, most natural way possible," says Fern Gale Estrow, M.S., R.D., a community nutritionist based in New York City. "People still want and need to save time in the kitchen, but they're not willing to sacrifice taste and nutrition to get it."

Fortunately, these five food trends provide exactly that -- flavorful, nutrient-rich meals that are easy to prepare and can help you fulfill many of your dietary requirements.

Flexitarianism

Like vegetarians, "flexitarians" eat a primarily plant-based diet composed of grains, vegetables, and fruits, but they occasionally obtain protein from lean meat, fish, poultry, or dairy. A quarter of Americans fit the description, consuming meatless meals at least four days a week, according to the American Dietetic Association.

Why it's here to stay: Flexitarianism is exactly what dietitians, nutritional researchers, and public health advocates have been recommending for years. "It's about eating a varied diet that's low in saturated fat and high in fiber," says Milton Stokes, M.P.H., R.D., chief dietitian at St. Barnabas Hospital in New York City, and an ADA spokesperson. Because the emphasis is on produce rather than protein, flexitarians are more likely than most Americans to meet the recommended daily intake of fruits and vegetables and the vitamins and minerals they contain. CookingLight.com: Take our quiz on correct serving sizes

What it means for you: Studies show that people who follow this approach to eating generally weigh less and have lower rates of hypertension, heart disease, diabetes, and prostate and colon cancer. In one large study from Tulane University in New Orleans, Louisiana, researchers tracked the eating habits of more than 9,600 people over a 19-year period and found those who consumed fruits and vegetables at least three times daily lowered their risk of stroke by 42 percent, and their risk of cardiovascular disease by 27 percent.

Locally grown foods

As people seek fresher foods, they have begun to connect with local family farms. Community-supported agriculture (CSA) programs and farmers' markets give consumers direct access to produce, meats, cheeses, breads, honey, and other foods that are produced in nearby communities. In the past 10 years, the number of local farmers' markets has more than doubled -- it is up from 1,755 to 3,706, according to the U.S. Department of Agriculture's Agricultural Marketing Service.

Why it's here to stay: Because they are so fresh, locally grown fruits and vegetables often have a nutritional edge over produce raised on "factory" farms. The latter, which constitutes most of the produce grown in the United States, is picked about four to seven days before it arrives on supermarket shelves, and shipped for an average of 1,500 miles before it's sold, according to Local Harvest, a nonprofit agricultural research group. All that downtime takes a toll. USDA researchers have found that if it's not handled properly, produce can lose up to half its nutrients in transit. Water-soluble nutrients such as vitamin C are particularly vulnerable.

What it means for you: "Buying food from local vendors gives you input," says Gail Feenstra, R.D., food systems analyst at the University of California at Davis' Sustainable Agriculture Research and Education Program. "You can find out how things were grown. You can also request varieties of fruits and vegetables that wouldn't be available elsewhere." And then there's the most important reason of all: Because of its freshness, locally grown food tastes better than produce designed to be shipped. "Growers' priority is on taste and texture versus transportation," Feenstra says.

Functional foods

Functional foods are enriched with nutrients that may not be inherent to a given food. Familiar examples include orange juice fortified with calcium or milk fortified with vitamins A and D. As sales of these foods have soared in recent years, more functional foods have reached the market, such as eggs and pastas with omega-3 fatty acids, sterol-fortified chocolates and high-fiber, high-protein flours.

Why it's here to stay: These foods help many people fill nutritional gaps. "For example, if you're lactose intolerant, you might find it difficult to meet your calcium quota," Stokes says. "Calcium-fortified juice eliminates that problem, especially if a glass is already part of your daily diet." Likewise, if you dislike seafood, you can obtain extra omega-3s from eggs or pasta. CookingLight.com: Remembering real portion sizes

What it means for you: Functional foods are one helpful element in maintaining a balanced diet, not a substitute for it. "Calcium-fortified orange juice won't supply other nutrients that a dairy source would provide, like protein," Estrow says. "That's why it's best to rely on whole foods, which provide multiple nutrients that act synergistically." In the end, it's fine to reap added nutrients from a functional food, but remember to fulfill the majority of your needs with naturally rich sources.

Organic food

These are foods produced following a government-regulated practice of growing and processing that minimizes exposure to pesticides, herbicides, and other chemicals used in traditional farming. Organic food is one of the country's fastest-growing market segments; sales have risen more than 20 percent per year since the 1990s, according to the USDA's Economic Research Service.

Why it's here to stay: Some organic foods may provide a nutrition boost. A research review of 41 studies conducted by the University of California at Davis found that, on average, organic produce contains as much as 27 percent more vitamin C, 21 percent more iron, and 29 percent more magnesium compared with traditionally grown foods. The kinds of packaged organic foods that now fuel the category's growth, such as cookies, baked goods, and boxed meals, also benefit from a similar perception of healthfulness.

What it means for you: "An organic stamp isn't necessarily a guarantee of nutritional quality, but it is a sure sign that the food is less adulterated," Stokes says. An organic cookie, for example, may have just as many calories and grams of saturated fat as a nonorganic cookie. But in the case of produce crops that are commonly treated with high concentrations of pesticides, such as peaches, apples, and strawberries, choosing organic can minimize your exposure to these chemicals, according to tests conducted by researchers from the Environmental Working Group in Washington, D.C. CookingLight.com: All-star foods that fight for health

Slow food

Launched in Italy 20 years ago by restaurateur Carlo Petrini, "slow food" was originally designed to protest the encroachment of fast food on the traditional Mediterranean lifestyle. The trend's principles -- choosing locally grown and produced items, preparing them in traditional ways, and eating with friends and family -- celebrate a relaxed approach to living that provides a welcome contrast to the fast-paced, eat-on-the-run lives many people lead.

Why it's here to stay: As with locally grown food, freshness is a key component of the slow food trend. "Investing the time to choose what's fresh that day will ensure that night's meal will be at its peak nutritionally," Stokes says. This principle applies whether you're making a family recipe or dining in a restaurant where the chef selects ingredients based on their seasonal availability. Family togetherness is also an important aspect of the trend. "Slow food is all about cherishing the eating experience and getting back to what food used to be: a vehicle for drawing people together," explains Sara Firebaugh, assistant director of Slow Food USA.

What it means for you: Healthful whole foods are a great start, but slow food goes a step beyond good nutrition -- and it's a difficult one to quantify. No scientific studies have conclusively proven that friends and family make better dinner companions than televisions, but the benefits are clear. "Slow food embraces the psychological component in food choices, meal preparation, and the act of eating," Estrow says. "A healthful diet isn't just about what you eat but how you eat it." E-mail to a friend

For more tips on making healthy taste great, try Cooking Light - CLICK HERE

Copyright 2009 Cooking Light magazine. All rights reserved.

Health and nutrition writer Maria Condo is a frequent contributor to Cooking Light. She lives in New York City.

@highlight

"Flexitarians" eat a mostly plant-based diet but sometimes add animal protein

@highlight

The number of local farmers' markets has more than doubled in the last decade

@highlight

"Functional foods," those enriched with extra nutrients, can fill dietary gaps

@highlight

Studies: Organic produce contains more nutrients than traditionally grown foods