(CNN) -- As events continue to unfold in Syria, the future of this Arab nation remains unknown.

There are many questions. Will the regime of President Bashar al-Assad eventually fall? If so, what kind of leadership would replace al-Assad? If not, would al-Assad's style of governance change?

The answers will have a major impact on Syria's neighbors and the Middle East.

It's a complicated web of affairs, laced with deep historical, political and religious ties. There are several factors to consider: Syria's relationships with Iran and Hezbollah; its presence in neighboring Lebanon, a country struggling to maintain a delicate balance among its religious and ethnic sects; and the roles of Gulf Arab states like Saudi Arabia and Qatar.

We asked four people to share their thoughts on the connection between Syria and the current state of affairs in the region, posing the question: "What kind of impact do the events in Syria have on the rest of the Middle East?"

Leverett: War could draw in other countries
Hillary Mann Leverett teaches foreign policy at American University in Washington. A former White House official who worked on Middle East issues, she held various roles with the State Department, the National Security Council and the U.S. Mission to the United Nations. She is also co-author of the blog RaceForIran.com.

The civil war in Syria is likely to prove a watershed for the Middle East's balance of power. It has the potential to become a full-blown regional war that could spill over into other countries and bring those countries into conflict, through proxies and perhaps even directly.

On top of that, the temptation to arm and fund Syrian rebels could spark a great power confrontation over Syria. Russia and China have made it clear that that they oppose foreign military intervention in Syria, especially by the United States. And in Russia's case, it has made it clear that it will protect Syria, its beachhead in the Mediterranean. Russia has a longtime relationship with the country, and it has drawn a red line against U.S. intervention. Russia has sent naval assets, weapons and radar to Syria, and it could even send Russian personnel to protect it. Russia and China's approach to the Syrian conflict is very different from the posture they took toward the U.S. invasion of Iraq and Western military intervention in Libya.

If you watch the Western or Gulf states' media, you would have the impression that everyone in Syria opposes and is fighting the government. This is not true. In Syria, a significant portion of the population is disaffected, but the majority still supports the regime. A series of public polls, for example, show that the al-Assad government still retains a majority of the support of the population. The reason? The basic majority, about 55% of the population, is terrified at the prospect of the other 45% forming a Sunni Islamist tyranny over the country. The 55% have held together -- as they have for decades -- to essentially hold Syria together as an independent, secular political order.

There are now several countries, principally Saudi Arabia, Qatar, Turkey, France and the U.S., that have aligned themselves with the angry minority. The strategic problem for these countries is that even if rebels are militarily successful and force al-Assad from power, the new government would be one that roughly 55% of the population does not want and/or fears. This means that without a negotiated way forward, we know that the outcome of arming or supporting the rebels means -- at a minimum -- only sustained violence and instability in Syria and for the region.

Tabler: 'Cold war' between Shiites, Sunnis
Andrew J. Tabler is the Next Generation fellow at the Washington Institute for Near East Policy. He is also the author of "In the Lion's Den: An Eyewitness Account of Washington's Battle with Syria."

The events in Syria impact the general struggle between Iran and the Sunni-Arab alliance in the region. The minority Shiite Alawite-dominated regime in Syria is backed by Iran, and the majority of Syrians are Sunni Muslims.

There is sort of a cold war taking place between the two sides. I think you can see that playing out in terms of Qatar, the United Arab Emirates, Saudi Arabia and Turkey clearly on the side of the opposition in Syria, while the Iranians are strongly backing the regime. What's at stake is larger than what's within Syria's borders.

Syria is a keystone of the Iranian alliance. It allows Iran to protect its power on the shores of the Mediterranean and its border with Israel, particularly its support of Hezbollah in Lebanon.

And the more this violence continues, especially with the regime using brutal force, the more it enrages people in the Sunni Arab countries. Although other governments have been holding back in their support of the opposition until recently, there are many individuals in the region who will help sponsor the opposition within Syria.

A lot of this is about the future of the Arab world and what the basis of these governments will be. For so long, it has been based on narrow regimes and, in the case of Syria, a narrow minority regime. Whatever comes next is likely to be a majoritarian system that has a larger base.

Haddad: Interference would change the dynamics
Bassam Haddad is the director of Middle East studies at George Mason University. He is also the homepage editor of Jadaliyya, an independent online Arab affairs magazine produced by the Arab Studies Institute. Haddad wrote "Business Networks in Syria: The Political Economy of Authoritarian Resilience."

The Syrian situation is complex like any other uprising, but the situation has added complexity because it is at the juncture of several conflicts in the region. Those struggles involve local, regional and international power plays that make the situation a lot more charged.

For instance, we have Syria at the center of the Arab-Israeli conflict. Syria is part of an axis, so to speak, with Iran and Hezbollah, confronting imperialism in various forms from inside and outside the region, particularly in relation to U.S. domination and Israel's occupations and belligerence.

There is also resistance to the conservative Arab camp that includes Saudi Arabia, Qatar and other conservative countries that are usually allies with the United States.

Also, Syria is, in many ways, the guarantor of stability in Lebanon. Syria's presence in Lebanon has guaranteed some stability despite many violations of Lebanon's sovereignty by Syria.

For all these reasons, Syria's position in the region is pivotal. This is not simply another uprising against a dictator. It is also being transformed by other players into an effort to redraw the political map of the region and curtail further protests elsewhere.

A lot of the anti-regime actors and analysts are placed in an odd position. They do not support the regime or the turn that the uprising has taken since fall of last year. So perhaps the task is to build an independent opposition away from the dictates of Saudi Arabia, Qatar or the United States.

Military intervention in Syria will bring in Iran and Hezbollah, and that will change the dynamic of the conflict. Most people in the region are opposed to the Syrian regime's domestic behavior during the past decades, but they are not opposed to its regional role. The problem is the Syrian regime's internal repression, not its external policies.

If there is no interference from the outside, the uprisings will be seen as legitimate. If it becomes regional and you bring in the U.S. and Israel in a fight against the Syrian regime, it changes the strategic dynamics of the conflict -- and not just the players involved.

Dunne: Democracy takes time
Michele Dunne is the director of the Atlantic Council's Rafik Hariri Center for the Middle East in Washington. Previously, she was a Middle East affairs specialist at the State Department and the White House. She also served as a diplomat in Cairo and Jerusalem.

When I travel to the Middle East, it is striking how in the eastern part of the Arab world, sectarian issues are right on the surface of public discourse and shape the way people look at the uprisings.

For example, the same person might support the uprising in Syria but not the one in Bahrain, or vice versa, depending on whether that person is Sunni or Shiite Muslim.

There are many reasons for this, including the rise of Iran and the unleashing of sectarian sentiments in Iraq after Saddam Hussein was deposed. Sectarian feeling is less pronounced in the western part of the Arab world, which is largely populated by Sunnis.

Last summer, Saudi Arabia and the other Gulf states abandoned al-Assad and withdrew their ambassadors from Syria. Perhaps they did this partly because they saw how strong the popular uprising in Syria was and assessed that al-Assad might not be able to outlast it. Perhaps they also saw a chance of getting a Sunni majority government into power in Syria, which would make the Gulf states more comfortable. Probably, their desire to change the regional sectarian and political power balance has largely dictated their policies toward Syria.

Certainly, Syria has been a key cog in the machine of Iran's influence in the Levant. Syria has provided the avenue through which Iran could project political influence into Lebanon and Palestine through Hezbollah and Hamas.

The Hamas link with Syria has already been broken. Hamas has turned against al-Assad, partly out of support for the Syrian Muslim Brotherhood and partly because Damascus is no longer a safe haven for them. Hamas is now working on closer relations with Egypt, where the Brotherhood controls close to half of the parliament, is running a candidate for president and is likely to have a strong presence in the new Cabinet.

We are not going to see in any of the Arab countries a neat transition to a democracy in a year or two. Countries do not make that shift -- from authoritarianism to democracy -- so rapidly. Achieving a well-functioning democracy could happen in perhaps 10 to 15 years. There will be setbacks, bloodshed and disappointments along the way. But we have to stay with this for a while, develop sustainable strategies to help these countries, and not abandon them a year or two into their transitions.

The opportunity to establish functioning democracies in the Arab world is a tremendous and historic one for the Middle East, and the risks if these transitions fail -- with all that could bring in terms of instability, safe havens for terrorists, etc. -- are also enormous.

The opinions expressed in this article are solely those of the authors.

@highlight

Whatever happens in Syria will have a major effect on its neighbors and the Middle East

@highlight

Expert: A regional war could draw in outside countries such as the U.S., Russia

@highlight

The sectarian power balance might change if the Syrian regime is deposed