Columbiana, Alabama (CNN) -- Shelby County is booming. The Birmingham suburb is lined with strip malls, subdivisions, and small factories, in what was once sleepy farmland. The population has grown fivefold since 1970 to about 200,000. Change is afoot in this bedroom community, at least on the surface.

But the federal government thinks an underlying threat of discrimination remains throughout Alabama and other parts of the country in perhaps the most hard-fought franchise in the Constitution: the right to vote.

Competing voices in this county, echoes of decades-long debates over equal access to the polls, now spill out in a 21st century fight, one that has reached the U.S. Supreme Court.

Veterans of forgotten voting war count the cost

"I think they are looking at this situation through rose-colored glasses," says the Rev. Dr. Harry Jones, a local civil rights leader, about the current majority white power structure in Shelby. "I think they have painted a picture to make the outside world believe that racism is no more. But if you dig beneath the surface I think you'll find what you are looking for."

A longtime county leader, however, says things truly have changed for the better.

"Here, now, in this decade, we have black registered voters at a percentage that is equal, and at some occasions exceeding, the voting of the white population," says County Attorney Frank "Butch" Ellis Jr. "It's hard to find that there's any discrimination here, and certainly there's nothing in the congressional record."

Major case for court this term

Now the nine-member high court is poised to rule in coming days on whether the key enforcement provision of the landmark Voting Rights Act of 1965 should be scrapped, as a constitutionally unnecessary vestige of the civil rights era.

Known as Section 5, it gives the federal government open-ended oversight of states and localities like Shelby County with a history of voter discrimination.

Any changes in voting laws and procedures in the covered states must be "precleared" with Washington. That could include something as simple as moving a polling place temporarily across the street.

The provision was reauthorized by Congress in 2006 for another 25 years. Shelby officials subsequently filed suit, saying the monitoring is overly burdensome and unwarranted.

This case is one of the biggest the justices tackle this term, offering a social, political, and legal barometer on the progress of civil rights in the United States and the level of national vigilance still needed to ensure minorities have an unburdened path to the election process.

High court poised for high-stakes rulings

Test of federal authority

Civil rights groups say Section 5 has proven an important tool to protect minority voters from local governments that would set unfair, shifting barriers to the polls. If it is ruled unconstitutional, they warn, the very power and effect of the entire Voting Rights Act would crumble.

But the provision's opponents counter it should not be enforced in areas where it can be argued racial discrimination no longer exists.

The appeal presents the court and its shaky conservative majority with two of the most hotly debated issues in politics as well as constitutional law -- race and federalism.

It will be a major test of Washington's authority, and the extent to which the central government may consider vestiges of voting discrimination that may still linger, potentially keeping some minority voters disenfranchised.

The Voting Rights Act was a monumental political achievement during the Civil Rights era. It banned such things as poll taxes and literacy tests that had long suppressed black voter turnout. States like California and Texas also have a history of discrimination against Hispanic voters.

In upholding the coverage requirements, the high court in 1966 succinctly summarized the law's purpose: "Congress felt itself confronted by an insidious and pervasive evil which had been perpetuated in certain parts of our country through unremitting and ingenious defiance of the Constitution," said the justices. "Congress concluded that the unsuccessful remedies which it had prescribed in the past would have to be replaced by sterner and more elaborate measures in order to satisfy the clear commands of the Fifteenth Amendment."

The act was to expire in 2007 but was extended by Congress to 2032. It places all or parts of 15 states with a record of past discrimination -- mostly in the South -- under strict requirements on election procedures.

The Justice Department has defended continuing use of the preclearance provision in court, but the NAACP has led the charge to raise public awareness of the case.

"Closing off the paths to the polls and by trying to deter people from voting is too often practiced and trained and focused on minority communities," said Debo Adegbile, special counsel with the group's Legal Defense and Educational Fund, who argued before the justices in February. "It doesn't happen everywhere but it happens too much."

Shelby County is 11% African-American, compared with 28% statewide.

Frank Ellis and his family have deep roots there. He is a former state senator and the county attorney for a half-century. His son, Corley, serves on the nine-member, all-white county commission.

From his comfortable law offices, Ellis was persuaded to bring this legal fight because of what he says is a fundamental question of inequality in the Section 5 regulatory scheme.

"Over the years we realized that this burden was unfair and unjustified," he said. "We just elected a black member of the board of education, with a 90% white population. We've elected a black mayor over a white incumbent, we've elected black city council members."

Many neighborhoods, he says, are integrated.

Fast facts: Top U.S. Supreme Court decisions

The dispute in Calera

Ellis acknowledges a voting dispute in the city of Calera was not handled well by local officials, but chafes at the assumption things are irreparably bad in Shelby County. He says it is especially hard to disprove a negative. He is convinced that no pervasive racial bias currently exists in the county power structure.

"The South has changed, it is not the same it was in 1964," Ellis said. "The whole country has changed. We are a dynamic society, not just in Alabama but everywhere."

Some have called the preclearance requirement a Scarlet Letter or badge of shame Southern states, mostly, must perpetually endure.

Racism, in the minds of many African-Americans and Hispanics in the county, is subtle and deep-rooted -- a "good ol' boy" system, as the Rev. Jones puts it.

He and other civil rights activists point to the 2008 election in Calera, where only one African-American was serving, Ernest Montgomery.

The city, over the objections of the Justice Department under its Section 5 authority, changed the voting boundaries, costing Montgomery his seat. He believes it was an effort to weaken minority voting strength.

"Some sub-developments were added to my district and diluted the African-American district from a 67% district down to about 28%," Montgomery told CNN. "I think of the possibility of what could happen if Section 5 could go away -- that some of the old mindsets would kind of fall back into place."

After the feds intervened, a new election was held and Montgomery got his seat back. He holds it today.

The government points out that some areas have gotten out of Section 5. In recent years, 31 cities and counties in Virginia successfully petitioned to be exempt from the preclearance requirements, though the rest of the state remains under federal oversight. New Hampshire was removed from federal oversight in March.

Shelby County has not made such a request; it opposes Section 5 on its face.

Opinion: Bring voting into the digital age

'Serious constitutional questions'

The Justice Department also said the Supreme Court had, in recent years, narrowed the scope of some aspects of the Voting Rights Act.

Justice Anthony Kennedy, who could prove a swing vote in the Alabama dispute, noted in an earlier unrelated case involving Section 5 that "racial discrimination and racially polarized voting are not ancient history."

But it may be Chief Justice John Roberts who is exercising the power to lead the tricky but crucial opinion-writing exercise.

That is because he authored that 2009 high court ruling, suggesting Section 5's days were numbered.

He said the preclearance provision raises "serious constitutional questions," and added it "represents an intrusion into areas of state and local responsibility that is unfamiliar to our federal system."

"Things have changed in the South. Voter turnout and registration rates now approach parity," Roberts said at the time, echoing the views Shelby County now makes in its appeal. "Past success alone ... is not adequate justification to retain the preclearance requirements."

The court for four years avoided the key question of the law's constitutionality.

Civil rights supporters worry the court's five conservative members will strike down this and another pending appeal over affirmative action in public college admissions.

Any dispute about voting slips inevitably into politics and efforts by both Republicans and Democrats to preserve their power bases.

Section 5 lawsuits have been acute in the past two years. They involve challenges to constitutionally mandated boundary changes in state and congressional districts based on the 2010 census; new, stricter voter identification requirements; and reductions in early voting periods.

Those fights are now clogging the federal courts.

Some conservative groups have argued that "ancient formulas" are being applied today, not to erase discrimination, but to benefit a particular political party. Some liberal activists counter Section 5 and federal oversight are being demonized by many on the right for purely partisan gain, and to divide Americans again over race.

In Shelby, both sides know the nation is watching and know the stakes will ripple widely.

"I'm not saying everything's perfect," Ellis tells CNN. "But I'm saying, very few of the non-covered jurisdictions can give you a success story like I've just given you out here in Shelby County."

"I agree that things have changed in the South and they are better," says Jones, senior pastor at New Mount Moriah Missionary Baptist Church in Calera, "but they haven't reached the point where we could do away with Section 5 yet.

"It's a lot better, but it still lives, discrimination still lives, and I'm not willing to trust (voting enforcement) into the hands of people whose motives are not pure."

The case is Shelby County v. Holder (12-96).

CNN's Joe Johns and Stacey Samuel contributed to this report.

@highlight

The leaders of Shelby County, Alabama, say preclearance is no longer needed

@highlight

Preclearance by the federal government is required for changes in voting procedures

@highlight

The Supreme Court is poised to rule on the question

@highlight

The case offers a social, political, and legal barometer on the progress of civil rights