(CNN) -- Amid all the furor about the seemingly omnipotent military in Egypt, the disbanded Islamist-dominated parliament and the debate over whether the Muslim Brotherhood will ban beer and bikinis, it's tempting to mutter, "It's the economy, stupid."

In 18 months of upheaval, all Egypt's economic indicators have headed south.

Growth is a projected 1.5% this fiscal year, far too feeble to provide a young and rapidly growing population with jobs (80% of Egypt's population is under age 30). Unemployment, one of the engines of the revolution, is estimated to be as high as 25% among the young. Tourism revenues have fallen sharply, and foreign reserves have dwindled to $15 billion. According to the United Nations, some 40% of Egyptians live below the poverty line; 14 million people subsist on less than $1 a day. Institutions are chronically weak and corruption is endemic.

President-elect Mohamed Morsi has his hands full.

Many critics say the military has handed Morsi a neutered presidency doomed to fail. But economists who have dealt with the Muslim Brotherhood's economic team describe the team as pragmatic, well-prepared and favorable to the free market.

Hernando de Soto, a noted economist who has helped his native Peru empower millions, has consulted with the Muslim Brotherhood. He says that when he met millionaire Khairat el-Shater, the Brotherhood's first presidential candidate who was disqualified for legal matters, el-Shater described himself as "businessman" on his card.

"They want to create a market economy for the poor, to bring them into the mainstream," de Soto says.

The Muslim Brotherhood has pledged to reach a rapid accord with the International Monetary Fund to cool Egypt's borrowing costs and protect the value of its pound. The interim military government raised money by selling bonds to Egyptian investors -- but at rising interest rates, with the yield on the one-year bill reaching a dizzying 16%. The new government will have to repay or roll over some $4 billion in short-term borrowing over the next six months.

There have been several rounds of negotiations between the Finance Ministry and the IMF for a $3.2 billion loan, but they have yet to yield an agreement. That amount may now be inadequate. Masood Ahmed, one of the IMF's senior officials for the Middle East, summed up the challenge last month: "How can we help Egypt now come up with an economic program that would restore confidence, protect poor people and vulnerable households -- and do so in a way that restores confidence during uncertainty?"

Hafez Ghanem, a senior fellow at the Brookings Institution who was recently in Egypt, says the immediate priority is to devise a "bold, credible program to reduce the outflow of reserves, encourage investment and bring in other donors" through an agreement with the IMF.

He advises the new government to focus on two or three priorities. The first is tackling corruption, which resonates with every Egyptian. "Real progress on corruption will have to involve a partnership between the government, the private sector and NGOs," he says.

He looks at the example of Indonesia. After the fall of President Suharto, the new government embarked on decentralization, partnering with nongovernmental organizations and civil society. Results were not immediate, but the perception of change was.

The second priority, Ghanem says, must be the subsidies that consume such a large part of the national budget.

The country's growing deficit could be cut significantly if fuel subsidies were removed. But that's not going to happen. The Brotherhood is anxious to protect the poor Egyptians who propelled it to power, even though 90% of the subsidy benefits the wealthiest 20% of Egyptians.

Fuel and bread subsidies have long been an essential insurance against civil unrest in Egypt. The challenge for Morsi and his government is to better direct them at those most in need. Ghanem says that over two or three years, the subsidy program can be refashioned as income support for the poorest, similar to the "bolsa familia" in Brazil that has lifted millions into the middle class. Gasoline stamps, graduated electricity tariffs and a shift in subsidies toward healthier foods -- away from bread and sugar -- all have a role to play, he says.

Ghanem says the issue of youth unemployment can only be addressed if the public debt is tackled, something that could have been done already with support from the IMF. But the interim government's refusal to consider foreign financing squeezed liquidity out of the domestic credit market.

Gehad el-Haddad, a senior member of the executive committee of the Brotherhood's Freedom and Justice Party, says he knows it faces a tall order.

"We are warding off the immediate devaluation of the pound and working to regain the trust of investors in the market, to assure them that stability will come under this presidency," he says.

One of their primary challenges, he stressed, is wiping away remnants of the Mubarak regime's hallmark bureaucracy and patronage networks: "The economy is our first, second and third priority."

Some still aren't convinced.

"I'm not sure I want to be investing my money when I know the Brotherhood, with little experience in this realm, is at the helm," says a senior member of losing presidential candidate Ahmed Shafiq's campaign. "It doesn't give me and many other liberals much incentive to invest in a civil state that might be compromised by Islamists with unclear motives."

Ahmed El Alfi, chairman of Flat6Labs, a start-up incubator based in Cairo that provides money and support to young entrepreneurs, says fostering entrepreneurship in Egypt is an oft-forgotten component of getting the economy on track.

"Really, this government should just get out of the way and let people work," he says. "The revolution gave people a sense of empowerment. Instead of calling up your dad to call up his friends to get you a government job, now Egyptians are thinking outside of the box, they want to make a difference. We have to nurture this talent, support creativity and harness the power as an economic solution."

But El Alfi worries that continued instability may prompt a brain drain among Egypt's brightest prospects. He notes that most of the budding entrepreneurs that seek Flat6Labs' mentoring are public school educated and from a lower economic bracket.

"These are the people who can't just pack up and move to the West if things get bad," he says. "And they can't be neglected."

Shadi Hamid, director of research at the Brookings Doha Center, says the Brotherhood knows this.

"Put simply, if they can't deliver on the economy, then they'll hemorrhage popularity," Hamid says. "They know they can't fail, and they're committed to delivering with a detailed free-market economic program that also focuses on social welfare."

De Soto says the key to Egypt's long-term prosperity is to find a way to liberate its anarchic "extra-legal" economy: the shopkeepers, craftsmen and traders who work below the radar to avoid corruption, taxes and the inertia of the bureaucracy.

That would require the streamlining of some 300 laws, he says, and the creation of one organization that could bestow property rights and provide the "extra-legal" with a path to a more productive role -- unlocking the vast sums sloshing about in the informal economy.

It would be a huge transformation, de Soto says, and it will require promotion and smart messaging.

"But there is a window of opportunity," he says. "That's what revolutions provide." The same happened in Japan immediately after World War II, unleashing an economy that had been in many ways feudal until then.

De Soto's consultancy, the Institute for Liberty and Democracy, was commissioned by the Mubarak government eight years ago to study Egypt's informal economy and concluded it was worth 55 times all the foreign direct investment Egypt had received since the Napoleonic era. But none of his recommendations was implemented.

De Soto reflects: "If you're going to change things, your enemy is the status quo."

Marwa Metwally, 23, is the sort of young talent that de Soto wants to see empowered. She's a razor-sharp unemployed college graduate who makes a four-hour commute every day from the Nile Delta governorate of Sharqiya to a nonprofit organization called Education for Employment in Cairo. She says the status quo simply can't continue.

"Though I didn't vote for Morsi in the first round, he can bring the change we need," she says. "The Brotherhood is from the poor, they understand. ... They were oppressed along with all us Egyptians the past 80 years, they have a plan and they know that we can't go on like this. We're dying. It's the breaking point."

But the short-term political uncertainties -- no parliament, a military perhaps committed to that very status quo and a ministerial team yet to gel -- will complicate decision-making. And given the speed with which Egypt's economy has deteriorated, time is a luxury the new government doesn't have.

@highlight

Egypt's economy is badly suffering after a year and a half of unrest

@highlight

It's now up to Mohamed Morsi and the new government to turn things around

@highlight

Obstacles include widespread corruption, growing national deficit