(Financial Times) -- The eastern Chinese city of Wenzhou produces more cigarette lighters and spectacles than anywhere on earth, and has long been seen as an economic trend-setter for the entire country. So reports that dozens of factory owners in the city have absconded in recent weeks, leaving workers unpaid and mountains of debt, are seen by some as an ominous sign for the national economy.

Slowing global demand for cheap Chinese exports, rising production costs and unsustainable levels of debt have combined to crush some of the country's most savvy entrepreneurs. In one tragic case, the owner of a Wenzhou shoe factory who owed more than Rmb400m ($63m) committed suicide three weeks ago. More than 90 other bosses have run away, according to state media.

Trade fluctuations in China, the world's leading exporter, are often seen as indicators of the health of the global economy -- and for some bearish investors, Wenzhou's problems are a sign that a hard landing is imminent for the nation. This is a dire prospect for the global economy at a time when most of the developed world is facing the likelihood of renewed recession.

In fact, the city's troubles are un-likely to trigger a drastic nationwide crash any time soon; most analysts believe China is on track for just a gradual slowdown in coming months.

But events in that city do represent a crucial turning point for the nation. "What's happening in Wenzhou is a reflection of the current Chinese model coming to an end," says Huang Yiping of Barclays Capital about the country's export-led, investment-driven growth paradigm. "China's economic success over the last 30 years has been built on cheap capital, cheap labour, cheap energy and cheap land but this has now produced huge imbalances and inefficiencies that are causing more and more problems."

The change will affect not just inhabitants of the world's most populous nation, where growth averaging 10 per cent a year for the past three decades has lifted hundreds of millions out of poverty.

It also heralds a structural change that will affect western businesses and consumers long used to ever cheaper Chinese goods. In addition, the shift will hit exporters in both developed and emerging economies that are increasingly reliant on China's appetite for raw materials to feed its investment and construction boom, which shows signs of running out of steam.

China's economic miracle began in 1978, when the Communist party launched market-oriented reforms granting farmers limited property rights and permission to sell anything they produced in excess of state quotas. This led to soaring agricultural productivity and rural incomes. It was followed by reforms encouraging mass migration, industrialisation and investment in a manufacturing sector that became known as the workshop for the world.

In 1990, income per capita was 30 per cent lower than the average for sub-Saharan Africa. Today, at more than $4,000, it is three times greater, according to World Bank data.

The unbeatable "China price" that attracted investors and buyers from all over the world was predicated on an endless supply of cheap, pliant labour; virtually free land; cheap and easy credit from state-owned banks; and heavily suppressed costs for inputs such as power and water.

But having drastically raised the living standards of almost a fifth of humanity, the formula is increasingly seen as defunct, and a contributor to serious problems including environmental degradation and rapidly rising social inequality.

"The drivers of China's meteoric rise are on the wane," says Robert Zoellick, World Bank president. "Resources have largely shifted from agriculture to industry; as the labour force shrinks and the population ages, there are fewer workers to support retirees; and productivity increases are on the decline."

With its world-class infrastructure and existing domestic and international supply chains, China will remain a global manufacturing base for some time to come.

But minimum wages are rising more than 20 per cent a year in many areas, and land is increasingly scarce and expensive. In addition, the government is reducing the supply of cheap credit and has moved to liberalise prices for energy and other utilities. Meanwhile, the flood of investment in new factories, roads, airports and housing estates that has been the main driver of growth looks increasingly unsustainable.

Back in Wenzhou, Xu Chuan, general manager of Xinhua Soft Packing, says times are tough. The business, which makes products from plastic bottles to zips, has been squeezed by rising costs and a lack of workers willing to take wages considered generous just a couple of years ago. "We are making much less money than before and in-put price rises are so serious it is hard to find many companies that are making money these days," Mr Xu says.

His predicament is partly a result of demographics. Many experts believe China's working-age population has already peaked and will decline in coming years, a trend exacerbated by the three-decade-old one-child policy.

It is also partly the price of success for the country's meteoric economic rise, which is lifting the prices of almost everything and shrinking the pool of impoverished workers willing to toil in factories or on construction sites for a pittance.

The country's leadership is well aware of the distortions that have built up in the economy; and freely acknowledges time is running out for a model that has served it so well. "China suffers a serious lack of balance, co-ordination and sustainability in its development," President Hu Jintao said in a recent speech. "We must accelerate strategic adjustment of the economic structure, scientific and technological progress and innovation, and the building of a resource-conserving and environmentally friendly society."

Beijing's latest five-year plan, which runs from 2011 until 2015, is packed full of vows to increase domestic consumption and wean the economy off its reliance on exports and particularly investment. But leaders have been talking for more than a decade about achieving these goals, and in fact the reverse has occurred. Consumption fell from about 45 per cent of gross domestic product in the late 1990s to an unusually low 33 per cent last year. Investment has hit a global high of 50 per cent of GDP.

"When reforms began 30 years ago, the investment rate was around 25 per cent of GDP and the economy grew at around 10 per cent a year, but now we are investing half of GDP for the same rate of growth; that tells you something about capital efficiency," says Mr Huang of Barclays Capital.

An involuntary shift from the old model appeared possible when the global financial crisis erupted in the west in 2008, triggering a collapse in global demand for Chinese exports, which fell by more than a third in the year to March 2009. Thousands of factories closed and more than 23m migrant workers poured out of cities such as Wenzhou.

In response, Beijing launched an economic stimulus package described by some economists as the biggest monetary and fiscal easing in history as it sought to cushion the blow to exporters. State-controlled banks were ordered to flood the economy with cash and local officials told to ramp up investment to jump-start growth. The result was a surge in credit-fuelled investment, particularly in residential property. In cities across the country, the results can be seen in forests of half-built apartment blocks, stadiums and convention centres.

To the rest of the world, the stimulus appeared an unqualified success, pushing headline GDP growth rates back up into double digits and stoking Chinese demand for imports, especially of natural resources. But the reliance on debt and investment accentuated all the distortions Beijing had already identified in its growth model -- and added the prospect of a serious property bubble.

Most analysts agree China's economy, now the second largest, is today less healthy and more imbalanced than before the crisis, and even more reliant on investment, particularly in property and infrastructure. "It's as if the economy ballooned in weight by eating too much in the way of resources and becoming obese," says Derek Scissors of the Heritage Foundation, a Washington-based think-tank.

While the model may be coming to an end, most economists believe China remains on track for a soft landing in coming months as growth moderates. GDP figures for the third quarter, due out on Tuesday, are likely to show annual growth that remains above 9 per cent. Even if a severe slump were to hit, Beijing would still have the option of loosening monetary policy to revive the economy in the short term, and re-versing steps to cool the red-hot property market and rein in credit made available by the stimulus package.

But there is unlikely to be a return to the boom years of the previous decade, when inflation remained dormant as GDP rose. Instead, growth will probably be 8 per cent or less, accompanied by persistent price rises -- HSBC predicts average consumer inflation of 5 per cent from 2011 to 2015, compared with 2 per cent from 2001 to 2010.

And now that China is the global production capital for so many of the world's manufactured goods, enduring Chinese inflation will mean higher prices for consumers the world over.

Beijing has identified the action it needs to take -- but many analysts believe it must do far more to hasten economic rebalancing towards consumption than its current efforts to provide better social services, build subsidised apartment blocks and encourage minimum wage increases.

"China has limited time to effect a radical political and economic shift," according to George Magnus of UBS Investment Bank. "If this shift doesn't start in earnest soon, the Chinese economy will succumb to a credit and investment bust from which significantly slower growth would follow, and this will be especially sensitive in a China where incidents of social unrest are increasing significantly in number, intensity and breadth."

© The Financial Times Limited 2011

@highlight

Manufacturing hurt by slowing demand for cheap Chinese goods, rising costs and debt

@highlight

"China suffers a serious lack of balance, co-ordination and sustainability in its development," said Hu Jintao

@highlight

Economists believe China remains on track for a soft landing as growth moderates

@highlight

There is unlikely to be a return to the boom years of the previous decade