(CNN) -- If austerity had been a clinical trial, it would have been stopped. As public health experts, we have watched aghast as a slow motion disaster arose from austerity policies in Europe, while politicians continue to ignore the evidence of their disastrous effects.

Austerity was designed to shrink debts. Now, three years after Europe's budget-cutting began, the evidence is in: severe, indiscriminate austerity is not part of the solution, but part of the problem -- and its human costs are devastating.

In the U.S., Greece, Italy, Spain, the UK and elsewhere in Europe there were more than 10,000 additional suicides from 2007-2010, a figure that is over and above historical trends, with the largest rises concentrated in the worst performing economies.

But suicides and depression are not unavoidable consequences of economic downturns: countries that slashed health and social protection budgets have seen starkly worse health outcomes than nations which opted for stimulus over austerity.

Greece, for example, is in the middle of a public health disaster. To meet budget-deficit reduction targets set by the European Central Bank, European Commission, and International Monetary Fund (the so-called troika), Greece's public health budget has been cut by more than 40%.

As Greece's health minister observed, "these aren't cuts with a scalpel, they're cuts with a butcher's knife." The spending was reduced to 6% of GDP, a figure lower than the UK, at 8%, and Germany, at 9%.

As a result, HIV infections have jumped by more than 200% since 2010, concentrated in injection drug users, as needle-exchange program budgets were cut in half. There was a malaria epidemic in Greece -- the largest in 40 years -- after mosquito-spraying budgets were slashed.

More than 200 essential medicines have been de-stocked from some pharmacies as the state's drug budget was reduced and pharmaceuticals companies exited the country in arrears.

Since 2008 there has been a rise of more than 40% of people who report being unable to access healthcare that they believe to be medically necessary, the majority concentrated in pensioners.

As patients cannot afford private care and forego preventive care, public sector hospitals have experienced a 24% rise in hospital admissions. Doctors and clinics are therefore overstrained. Infant mortality rates have risen 40% between 2008 and 2010.

Over 35,000 public health workers, nurses, and doctors have lost jobs. Unemployment rates have hit 27% and youth unemployment has jumped to near 75% in some areas.

With little hope for the future, desperate people are turning to cheap, synthetic drugs. Use of anti-depressants has skyrocketed, adding costs to the healthcare system. Suicide rates, previously among the lowest in Europe, have soared.

Were these all inevitable consequences of recession, rather than consequences of austerity? Of course the Greek financial and political elites have made mistakes. And of course Greece's fiscal and monetary options were severely restricted as part of the bailout deals. But the suffering of the Greeks was not inevitable.

The timing of many of these health effects coincided not with the onset of recession in 2008 and 2009, but with the implementation of deep budget cuts starting in 2010.

Several prevailing myths are commonly offered as alternative explanations for Greece's devastating health outcomes, including these three:

The first myth: "Greece's healthcare system is excessive and inefficient." But there are just five hospital beds in Greece per 1,000 people, versus more than eight beds per 1,000 people in Germany.

The second myth: "Greeks are lazy." But in 2011 the average Greek citizen worked 2,038 hours per year -- 600 hours more than the average German, according to the OECD.

The third myth: "Europe's bailout money is being squandered." But bailout money is not flowing in to support Greece's healthcare system -- it is instead circulating back to large international banks in Germany, France and the UK.

What we learned from analyzing past crises is that people do not inevitably get sick or die because the economy has faltered. Fiscal policy can be a matter of life and death.

During the Great Depression in the U.S. in the 1930s, mortality rates actually fell by about 10%. Even though suicide rates increased among the unemployed between 1929 and 1933, this increase was outweighed by short-term drops in road traffic deaths, as people drove less to save on fuel costs.

Then, at a time when total debt was over 200% of GDP, President Franklin Roosevelt implemented the New Deal, which created the U.S. social safety net. New Deal programs to re-house people who lost their homes, help people return to work, and build a public health infrastructure were highly effective -- and each additional $100 per capita in New Deal spending reduced suicides by 4 per 100,000 and infant deaths by about 18 per 100,000.

Tuberculosis rates also fell, but disease rates were substantially reduced in those states that aggressively implemented the New Deal rather than those avoiding its implementation -- a "natural experiment." 1934, the year after the New Deal started becoming effective, marked the beginning of the U.S. economic recovery.

Another "natural experiment" occurred in the aftermath of the East Asian financial crisis from 1997 to 1998. Indonesia, Thailand, and Malaysia all had large market crashes: their currencies plummeted, GDP collapsed, and unemployment soared.

But their politicians responded differently to the crisis, creating a rare laboratory in which we can identify the health effects of economic policy. Indonesia and Thailand turned to the IMF for help, implementing deep cuts to its HIV prevention, whereas Malaysia charted a different path, investing in preventive measures during the crisis.

Indonesia and Thailand suffered large pneumonia and tuberculosis outbreaks, but Malaysia avoided these effects.

Turning to the current recession in Europe, Iceland is another case study revealing that there is an alternative to austerity. Five years ago its three largest banks failed, and their total debt rocketed to over 800% of GDP. It was the largest banking crisis in history relative to the size of an economy and it forced Iceland to turn to the IMF for help.

The troika's bailout plan called for reductions in spending equivalent to 50% of the budget in order to finance bank bailouts. The health minister resigned in protest at plans to cut the healthcare budget by 30%, as detailed in our book.

Then the president of Iceland took a radical step: asking the people what they wanted to do.

In March 2010, 93% of the Icelandic people voted against financing a bailout for foreign savers of Icesave Bank through draconian budget cuts. Instead, Iceland stabilized healthcare spending.

Thanks to this boost to the nation's universal healthcare system, no one lost access to healthcare even as the cost of imported medicines rose as an effect of the devaluation of the Icelandic Krona.

There was no significant rise in suicides or depression. Nor were there any significant infectious disease outbreaks. Indeed, last year GDP growth was 2.7%, and unemployment rates have fallen below 5%.

Having seen the results, the IMF turned tail, praising Iceland's successful approach.

Each of these crises -- America's Great Depression, the Asian financial crisis, and Iceland's bank meltdown -- had different origins, but they led to potentially similar health threats. But their contrasting outcomes support our conclusion that an economic crisis does not inevitably increase in death and disability. The real danger is austerity.

But if austerity is not working, and indeed is part of the problem (as the IMF has recently admitted), why are European leaders continuing its pursuit?

British economist John Maynard Keynes indirectly outlined the dangers of austerity in 1919. Germany's unpayable debt from World War I, he argued, exacted by European nations in the Treaty of Versailles, would cause economic collapse and, ultimately, social instability in Germany.

Tragically, his premonition was borne out: Germany's deep austerity under "hunger chancellor" Heinrich Bruning as it struggled to repay debts to France, Belgium, and the U.S. fueled the rise of the Nazi party and, as some historians argue, ultimately World War II in Europe.

In the aftermath of that war, West Germany benefited from the U.S.-sponsored Marshall Plan, whereby America injected $1.45 billion in funds to invest in German industry and rebuild vital infrastructure. The Marshall Plan's stimulus package helped spur recovery, paving the way for decades of prosperity and peace in Western Europe.

Collectively we seem to be losing sight of the lessons from our past. In Greece, austerity packages in Europe are sparking the rising popularity of neo-Nazi parties, such as Golden Dawn.

But there is an alternative. In 2009, the German parliament approved a 50 billion euros stimulus package to spur growth. Across Europe we have found that economies that introduced greater stimulus investment have charted faster economic recoveries.

Thanks to smart investments in "active labor market programs"â€”programs that help people access job retraining and return to work quickly-- Germany, Sweden and Iceland have mitigated rises in depression and suicides from unemployment.

Our research has found that each euro invested in public health can yield up to a three euros return if invested wisely in data-supported government programs.

New York City officials learned this lesson in the early 1990s -- after restricting its TB prevention budget, the city suffered a drug-resistant TB outbreak that ultimately cost $1.2 billion to control, about 10 times greater than the estimated price of prevention.

Greece's HIV, TB, and malaria epidemics will now cost more to control than they would have been to prevent, our research indicates.

What we have learned is that severe, indiscriminate cuts to vital social protection programs are not only economically self-defeating, but fatal.

@highlight

Health experts David Stuckler and Sanjay Basu say that if austerity had been a clinical trial, it would have been stopped

@highlight

They have analyzed how austerity affects health and have found it drives up suicide, depression and illness rates

@highlight

They say the suffering of Greeks is not inevitable, with history showing stimulus can work better than austerity

@highlight

The authors argue the world has forgotten lessons from the past, and this is proving fatal