(CNN) -- There are dozens of ships, aircraft and helicopters searching for missing Malaysia Airlines Flight 370 in an area nearly as big as the continental United States.

Now, 4-day-old satellite images have provided a much-needed lead: two objects spotted bobbing in the southern Indian Ocean, about 14 miles apart.

The race is on to find those objects -- which experts caution could just as well be lost shipping containers as a chunk of fuselage or wing -- and by analyzing currents and other data perhaps locate the site where the plane might have gone down.

Let's say they find it. Would the mystery be solved?

Hardly. Finding the aircraft is just the beginning.

Assuming that the plane crashed and that it's on the bottom of the ocean, search crews would face myriad obstacles in recovering parts of the plane and in piecing together what happened.

And the treacherous waters of the southern Indian Ocean would only add to the challenge, said John Blaxland, a senior fellow at the Australian National University and expert on Australia's radar systems.

"The problem is that that piece of flotsam and jetsam is not where it was when the photograph was taken four days ago. The currents have taken it a long way eastwards," he said.

"So the aircraft are looking, in poor visibility, and this is the area that we used to call the 'Roaring Forties'; this is in the 19th century the kind of waters that ships got wrecked in. So this is really treacherous stretches of water, not easy to work in, very hard to detect things in."

The cases of TWA Flight 800 and Air France Flight 447 hint at the difficulties that might lie ahead.

The first demonstrates how tedious reconstruction work is and how important that work is to explaining exactly what went wrong, while the second shows just how long an ocean recovery can take.

"First thing to do is get back those recorders because ... there's a huge amount of data in the flight data recorder and the cockpit voice recorder. Get those back, and then we can see what we need to do next. But, you know, time is of the essence," said Tom Haueter, former director of the National Transportation Safety Board's Office of Aviation Safety.

He knows what he's talking about.

How do passenger jets change flight paths?

Debunking conspiracy theories

Haueter investigated the July 1996 crash of TWA Flight 800, which exploded in midair shortly after takeoff from New York, killing all 230 people on board.

His job began at the bottom of the Atlantic Ocean. U.S. Navy and other divers spent more than 1,600 hours scouring for clues.

"We found pieces from just forward of the center section of the wing. Then we found the nose of the aircraft. And then we found the wings and the tail, the engines and everything else further down the flight path," Haueter said.

The NTSB ruled that the explosion was caused by an electrical short circuit, which detonated the fuel tank and caused the Boeing 747 to break into pieces in the waters off Long Island.

The evidence was pieced together from a debris field of 75 square miles. Thousands of fragments were pulled from a tangled web of wires and airplane skin.

"We map the bottom. You start recovering things. You get back seat cushions, victim remains, and what you do is X-ray everything, because you're looking for an explosion. You're looking for fast particles that may have been captured by a seat cushion or a body." Haueter said.

As awful as it is to think about, recovered bodies can provide critical clues about a flight's final moments.

Haueter said, "Take a look at all the information. Is there burning on the bodies beforehand? We'll get autopsies. Is there soot in the trachea showing that there's fire on board?"

In the case of TWA Flight 800, extracting the wreckage from the water and reconstructing it was critical to debunking various conspiracy theories.

Witnesses said they saw a streak of light and a fireball, leading to suspicions that terrorists struck the plane with a rocket. Others blamed a meteor or a missile.

Piecing the aircraft together was necessary to get a fuller picture.

"We take a look at everything we have here, and what we couldn't find anywhere in TWA was any evidence of being hit from a missile from the outside," Haueter said.

Why were there no phone calls?

Findings released three years after flight

Like that flight, the experience of Air France Flight 447 provides clues about what could happen if Malaysia Airlines Flight 370 is found at the bottom of the ocean.

On June 1, 2009, Air France Flight 447 was en route from Rio de Janeiro to Paris when communications from the Airbus A330 ended suddenly.

Its last known position -- two to four days by ship from the nearest ports -- and the ocean's depth hindered search efforts.

It took four searches over the course of nearly two years to locate the bulk of the wreckage and the majority of the 228 bodies in a mountain range deep under the surface. It took even longer to find the cause of the disaster.

"We had three autonomous underwater vehicles -- basically unmanned submarines that swim programmed tracks over the sea floor. They'd go back and forth using acoustic sensors to map the sea floor, and from those maps, we could detect the wreckage site," said Mike Purcell with the Woods Hole Oceanographic Institution.

In May 2011, the aircraft's voice recorder and flight data recorder were recovered from the ocean floor after an extensive search.

It was not until July 2012 that investigators published their report, which blamed the crash on a series of errors by the pilots and a failure to react effectively to technical problems.

Malaysia has warned that it does not have the kind of submarine technology used to find the voice and flight data recorders for Air France Flight 447. So there's no time to be lost in tracking them down before the batteries powering their locating device run dry.

David Gallo, also with Woods Hole, helped lead the search for the recorders of Air France Flight 447.

He described what would happen once some debris from Malaysia Airlines Flight 370 is found, though he stressed there's still no evidence the plane hit the water.

Because of currents, the wind and new information, the search area is getting bigger by the day.

"Once a piece of the debris is found -- if it did impact on the water -- then you've got to backtrack that debris to try to find the 'X marks the spot' on where the plane actually hit the water, because that would be the center of the haystack," Gallo said.

"And in that haystack, you're trying to find bits of that needle -- in fact, in the case of the flight data recorders, you're looking for a tiny little bit of that needle," he said.

'We are flying partially blind'

Blaxland is similarly blunt about the challenges even in finding the two objects picked up the satellite in the southern Indian Ocean, let alone finding a potential crash site and recovering the plane.

Even with the help of the "best surveillance technology on the planet" on the P-3 and P-8 maritime surveillance aircraft, "it's still really hard in this kind of environment to pick up these little, semi-submerged blips," he said. "You're looking for something that potentially isn't even there any more."

Although the technology will pick up subsurface objects, he said, "the problem is, you've got limited resources; you've got limited flying hours.

"This is a long way away from the Australian shore. This is at the upper reaches of the flight capacity of these aircraft. They can only stay out there for a couple of hours, and this is a massive stretch of water we are talking about trying to cover.

"So, unfortunately, are flying partially blind here. We've got out-of-date information. The currents have moved the flotsam and jetsam to another location which we cannot locate.

"There's no emanations we are picking up to identify where that would be, and this means it's really a needle in the haystack."

Pinger locators

The southern Indian Ocean is often described as one of the most remote locations on Earth. Recovery specialists -- as well as the U.S. Navy -- often use locators to find the ping emanating from a flight recorder of a commercial aircraft.

"If the debris is verified, then there are pinger locators that are simple (boat-)towed hydrophones that can look for the signals of those pingers while they're still within that 30-day life expectancy of the battery," said Mike Williamson, who runs a Seattle engineering firm specializing in deep-sea searches of planes and shipwrecks.

"If that's possible, that can really give a much better idea of where the wreckage is," he added.

The middle of an ocean is a daunting environment, however.

"But in those conditions and the remoteness of the area, I'd be rather surprised if they can get a pinger locator out there and get any thing -- because at this water depth, the range is very limited on listening to those pingers," Williamson said.

Latest updates on the missing Malaysia Airlines jetliner

If this is the debris of Malaysia Airlines Flight 370, what happens next?

Anger as relatives confront officials

Difficulties may hamper Flight 370 search

Searching for the plane truth -- amid speculation

CNN's Michael Martinez, Dan Simon, Augie Martin and Jack Hannah contributed to this report.

@highlight

NEW: If debris is verified, recovery teams could use 'pinger locators' to find device

@highlight

Ships, aircraft and helicopters are searching for Malaysia Airlines Flight 370

@highlight

Let's say they find it. Would the mystery be solved?

@highlight

TWA Flight 800 and Air France Flight 447 provide clues about what could happen next