Washington (CNN) -- The State Department is using cutting-edge data gathering technology to help keep the peace in some areas and keep violence from flaring in others, saving both physical and fiscal costs of conflict.

"We are about breaking and interrupting, stopping and preventing atrocities and destabilizing violence, for the good of the people in the countries where we work, as well as the good of the American people," said Jerry White, deputy assistant secretary for partnerships and learning in state's newly formed Conflict and Stabilization Operation (CSO) office.

White, a Nobel laureate, encountered first-hand consequences of miscalculated foreign policy decisions, violence, and instability, when he lost a leg to a land mine during a hike in Israel in 1984. That led him to co-found Survivor Corps, which is the first international network of survivors helping survivors to recover from war, rebuild their communities, and break cycles of violence.

CSO analyzes "large data sets" as well as "civil society" generated data -- essentially the sum of patterns, human behaviors, electronic signals, social media elements and everything tangible that creates masses of technological and non-technological data.

"As observers of patterns, data, and focal points, we look at violence as an epidemic that can ultimately spread," White said. "As interrupters of violence, by using the nuances such as data analytics we now have the technology to prevent, interrupt and break these cycles of violence."

Iraq and Afghanistan

State Department officials said they didn't want to speculate the "should have, could have, would haves," but Mark Abdollahian, a political-scientist and co-creator of "Senturion", a "large data" predictive analysis tool, says otherwise.

In conjunction with the National Defense University, Abdollahian ran a forecast using big data analytics during the run-up to the war in Iraq, which was a fairly accurate preview of where the conflict would go.

Abdollahian's model anticipated what the Iraqi and international political support would look like if the United States went into Iraq with and without the United Nations support. It found very early on that if the United States entered Iraq on its own, "it would be the ultimate source of Iraqi sectarian and domestic violence."

It also predicted "the situation in Iraq would worsen throughout 2003 and 2004 in terms of Iraqi attitudes toward the U.S. presence as well as insurgent activity," said Abdollahian, whose Senturion model is now used by White and his team at CSO.

The model produced very specific predictions about the behavior of factions and accurately predicted the timing of defections as well as the potential support from unexpected allies -- such as the specific behavior of Shia leaders after Saddam Hussein's regime collapsed â€” to the point of even accurate sequencing of defections among different factions.

"When we published our findings with NDU, everyone was asking how we did this -- questioning whether or not we had inside deals. And we simply responded by saying we only looked at patterns, behaviors, and ran data -- yet everyone was shocked," Abdollahian recalled.

An alternative to 'top-down' approach

Both White and Abdollahian believe that this "large data analytic technology" provides a "focal point" and identifies the players in what Abdollahian calls a political "tug of war."

Software allows analysts to map "different people, players, stakeholders, and people with interests, in various targeted political landscapes." Then the computer chip tracks interactions among these elements -- Abdollahian's "tug of war" -- and therefore "anticipates if people are going to agree, and if so, what are the compromises, and if not, what are the potential outcomes."

The technology allows U.S. policymakers to frame responses in a timely manner and avoid conflicts that might require the introduction of military forces, reducing the cost in both money and casualties by identifying innovative courses of action that may have not been spotted without the use of this new technology.

White suggests the data-driven approach is somewhat contrary to the conventional "top-down" wisdom, since "many believe that it take decades to get into conflicts and consequently it would take the same amount to come out."

Amir Bagherpour, a senior analyst at CSO and former student of Abdollahian, suggests "mixing new technologies with conventional methods of developing policy strategies, creates "pockets of hope that allow advanced planning around the patterns of violence for the future."

AB Paul, cyber strategist and former policy adviser at the Pentagon and the U.S. Central Command, believes that people's emotions are a pivotal element in data analysis and capturing these human elements are a huge challenge.

"If you could apply human judgments, it's wonderful, otherwise substituting human judgment and talent with computing analytics does not work," Paul said.

Paul's argument is central to what White and Bagherpour regard as pivotal element in their work at the CSO.

"The key to success is to combine this nuance and technology with the invaluable talent, knowledge and human power of our diplomats and civilian responders through a comprehensive team effort," Bagherpour said.

Decoding Syria

One of the main areas of focus for the year-old agency is Syria, which is similar to many less-developed countries that lack cyber data availability.

Gary Shiffman, a former chief of staff of customs and border protection at the U.S. Department of Homeland Security, said "you want data to allow you to see" life's normal patterns.

"So this model can work as effective both in developed countries as well as undeveloped countries," said Shiffman, who is now president of Giant Oaks, a consulting firm that provides big data analytics for national and homeland security interests.

Shiffman suggests useful data in less developed countries can be found in "economic data -- what people are buying in stores, what cars are they driving, what kind of phones are they using, refugee flows, the direction of their move, mobile use."

Both Shiffman and White believe traditional data and civil society patterns can be as valuable for data analytic forecasts as cyber data that's more prevalent in developed countries.

"In the case of Syria, we look at trends, where the business leaders gather, what they talk about, where are the religious leaders; we follow sermons, political and religious statements, public meetings, statements in commerce and business areas," White said, suggesting that through this accumulation of information, they see connections in Damascus, Turkey and elsewhere and can project connections within the region.

CSO's analysis of large data and civil society enabled the Syrian opposition to build mass-communications and improve internal and external communications networks and develop civilian leadership capacity for if there's a change in government.

Introducing new narratives

In a post-Gadhafi Libya, White said the United States and its allies were under the impression that "militias" were one of the big problems in that country.

As a result, White and his team "dug down and looked at who are these militias? Where are they located? And how is the pattern of violence manifested?" through the study of human patterns and civil-society data-gathering.

"Libyan streets became our study ground, as did civil society and social media," White said.

By using large data analysis in a strategic effort to advance stability in Libya, "it was not your typical police, but rather the Libyan civil society that was the antidote to the militia violence," White said.

By looking at social networking, open sources and the civil society, analysts got a better picture of Libyans' attitude toward Americans, which helped "understand trend lines against Americans â€” that potentially led us to learn that Libyans were simply horrified -- Libyans were actually horrified -- by the killing of Ambassador Chris Stevens," White said of the U.S. diplomat who was killed in a terror attack on the American diplomatic compound in Benghazi last September.

Moving forward, White suggests that by looking at these reactions, instead of a military and counter terrorism approach, we can build-up "myth-busters" and thus introduce new narratives that can help prevent violence, not just in only Libya, but the region at large.

Thousands of miles away from where the Arab Spring bloomed, CSO is applying similar methods in Kenya, where more than 1,000 people were killed and 350,000 displaced after the 2007 elections. Last year White and his team integrated similar patterns of large data analysis to help Kenyans prevent violence during last month's elections.

North Korea is another conflicted area that remains a pivotal threat not only for the United States but also for the rest of the world. Both Abdollahian and Raphael Carland, director of partnerships and communication at CSO, say the area lacks readily available "information clouds" that make up the first layer of large data analysis. But by using its analytical tools, it's possible to fill in data gaps by correlating conditions in comparable environments.

Preventing another Boston

There is also strong potential in using large data analytics in the United States to help forecast terror attacks like the bombing at the Boston Marathon two weeks ago.

"Absolutely we can make this work domestically in the U.S., however the challenge is that people guard their privacy from the government very closely, so then we might face privacy-issue challenges when running human patterns and large data in the States," Shiffman said.

@highlight

Analyzing human behavior, social media, other data points a State Department tool

@highlight

Modeling looked at Iraq, Syria, Libya, North Korea and other hot spots

@highlight

Data-driven approach is contrary to conventional "top-down" wisdom

@highlight

Potential to use data analytics in the United States to help forecast terror attacks