Washington (CNN) -- It's a familiar refrain from the media-shy U.S. Supreme Court: Judge us by what we write in our rulings, not in oral arguments, speeches or interviews.

But the court term that ended this week in dramatic fashion reveals how difficult it can be to create a coherent picture of this dynamic bench, one that moves easily, if stealthily, across ideological lines on a range of hot-button cases.

This body, led by a relatively youthful 58-year-old chief justice, is one that is thinking long-term: conservative and cautious.

The drama that played out over three days looked like a ping-pong match:

• On Monday the court allowed affirmative action to continue in college admissions, while making it tougher in the future for public institutions to promote diversity in the classroom. Two liberal justices agreed with the five conservatives.

Supreme Court sidesteps big ruling on Texas affirmative action

• Tuesday, it was back to a familiar 5-4, conservative-liberal split when the majority struck down the heart of the Voting Rights Act, leaving the federal government without its major enforcement tool to fight discrimination against minority voters.

Court strikes down part of historic voting rights law

• And the finale Wednesday, giving gay rights supporters a major political and social boost by striking down part of a federal law that did not recognize same-sex marriage in states where it was legal and essentially clearing the way for homosexuals to wed in California.

Same-sex marriage rulings hailed as historic victory

One case was split along ideological lines, with moderate-conservative Justice Anthony Kennedy the "swing," or deciding, vote; the other produced an unusual coalition in the 5-4 divide. Missing was an overarching "equal protection" right allowing gays and lesbians to marry in all states. The court is nowhere near that legal destination.

So anyone in the political branches hoping for reliability from the current court, especially on social issues, may be disappointed.

"This is a conservative court -- conservative ideologically and conservative in the sense that they like to take baby steps," said Thomas Goldstein, publisher of the well-respected SCOTUSblog.com. "There are times when the court decides to act aggressively over time, for example limiting the use of race in government decision-making like affirmative action. Then there are other times when the court is more uncertain and wants to move more modestly. In the same-sex marriage cases it doesn't want to force the entire country in one direction or another."

By the numbers

It may surprise some, but the nine justices, despite their ideological differences, do like each other personally. And they readily find room for agreement. Sometimes.

Half the 78 decisions from argued cases this his term were unanimous, 9-0. But 30% were split 5-4, including voting rights, the two same-sex marriage cases, DNA testing for arrested criminal suspects, government electronic surveillance, and Native American adoptions. That is a higher percentage than in past years, according to SCOTUSblog, which annually compiles the numbers.

Ten of the 23 cases decided by one vote had the familiar five conservatives prevailing: Chief Justice John Roberts and Justices Antonin Scalia, Kennedy, Clarence Thomas, and Samuel Alito. But six times Kennedy sided with his more progressive colleagues: Justices Ruth Bader Ginsburg, Stephen Breyer, Sonia Sotomayor and Elena Kagan.

In probably a first for this court: Thomas -- perhaps the most right-leaning -- was the decisive vote when he joined the four liberals in a criminal sentencing appeal. Scalia, too, was a friend of the left on several other criminal procedure cases. Cockeyed coalitions seem almost routine.

But the figures overall show what court watchers have long known: Roberts, and especially Kennedy, played the greatest behind-the-scenes roles.

Kennedy was in the majority 91% of the time this term, and in the majority 87% of the time in the 5-4 cases. That includes the three blockbusters this week, a display of the power he wields.

Kennedy often high court's swing vote and power broker

Kennedy, who turns 77 next month, separately offered a broad embrace of gay rights, but a limited endorsement of federal authority in voting rights.

Colleagues on the losing sides of the biggest cases spared no rhetoric slamming Kennedy's personal views of the court's "primary role in determining the constitutionality of a law" as he wrote in the federal Defense of Marriage Act case, overriding the will of Congress.

In supporting DOMA, Scalia said Kennedy was promoting "judicial supremacy" over the other branches of government.

In supporting the Voting Rights Act and the power of Congress to oversee states with a history of minority discrimination, Ginsburg noted the "sad irony" when she said, "Hubris is a fit word for today's demolition of the VRA. ... Where is the court's usual restraint?"

Even lawmakers have learned to accept the you-can't-win-them-all reality of the court's jurisprudence.

"As disappointed as I was yesterday, I am happy today," House Minority Whip Steny Hoyer, D-Maryland, said when the same-sex marriage decisions were announced.

Roberts rules

If Kennedy is on the winning side more than any of his bench mates, the chief justice is not too far behind.

Roberts' key role crafting the opinion striking down part of the Voting Rights Act came after years of careful, incremental strategizing to limit the effect of racial classifications. In 2006, with just months on the job, Roberts lamented, "It is a sordid business, this divvying us up by race."

A year later discussing a case that struck down a voluntary school integration plan, he said firmly, "The way to stop discrimination on the basis of race is to stop discriminating on the basis of race."

Then in 2009, Roberts and the conservatives on the court sent a clear message to Congress: Fix the Voting Rights Act and its federal enforcement scheme or the court would have "no choice" but to act as the constitutional arbiter. When lawmakers did not respond, the court in large measure did as it promised this week, in stunning fashion.

President Barack Obama said he was "deeply disappointed" in the decision, quite a shift from a year ago when Roberts led the court in upholding the Affordable Care Act, the president's signature health care reform effort. Back then the president called that decision "a victory for people all over this country."

While Kennedy dominates the 5-4 decisions, Roberts was in the majority only 61% of the time. But many conservative legal scholars say the chief justice has a years-long view of the law and of his own power. That gives them hope for the future, even when they do not prevail today.

"It's disappointing to see the representatives of the people in Congress having been overruled here," said Carrie Severino, chief counsel at the Judicial Crisis Network, about the DOMA ruling. "But I think the silver lining is that we see, as the chief justice pointed out, that actually this is a somewhat narrow decision in terms of leaving it to the states to be worked out there in the future."

What worries many progressive activists is the conservative court's consistently united voice on business-related cases, which typically dominate the docket. These disputes don't generate the same political pulse as race and marriage, but carry a hefty legal consequence.

"As opposed to issues like the dismantling of affirmative action, where the court's conservative bloc is divided and has trouble agreeing about how far and how fast to take the law, the court's conservatives are completely united" on this front, said Doug Kendall, head of the Constitutional Accountability Center. "Corporate America wins; workers, consumers, mom and pop shops, and other individual Americans asserting their rights in federal court lose. Again and again."

The excitement of this term will spill over when the justices resume their work in October. Among the closely watched petitions:

• Another affirmative action dispute and a Michigan voter referendum that bans racial preferences in public university admissions, state employment and government contracting.

• Public prayers in town council meetings.

• The validity of Obama's recess appointments to a federal agency when the Senate was in a "pro forma" session.

Each member of the court at some point in their tenure begins to think about a personal legacy. Some of the (relatively) younger ones may think long-term; the elder justices may realize they only have a few more years to make their mark. Three of the justices are in their 50s, three are in their 60s or early 70s; three are 75 or older.

That and the shaky ideological makeup create a court with subtly different agendas and demands. The tension over the 5-4 cases, the mixed-result efforts by Roberts to forge consensus, and the fact each of the chambers operates essentially as their own independent judicial shop means fixing a unified adjective on these nine justices is impossible.

Several of the justices privately acknowledge this unique relationship among themselves. As one told CNN a few years ago, "If we can agree, we will. If we can't, we don't. That's how we look at it, and that really is how it has been, at least as long as I have been on the court. And I expect it will continue."

@highlight

Supreme Court term ends this week in dramatic fashion with rulings on three hot-button topics

@highlight

Chief Justice John Roberts and Justice Anthony Kennedy are power players on the court

@highlight

Expert: The court is conservative ideologically and in that "they like to take baby steps"

@highlight

Next term the court will consider the validity of some of President Obama's recess appointments