Lawrenceville, Georgia (CNN) -- You might recognize prominent primatologist Frans de Waal from lectures he has given about his research on primate behavior, which have been popularized on YouTube.

His face is familiar to chimpanzees, too; some chimps that he knew as babies still recognize him even after decades apart, he said.

"Chimpanzees have the advantage that you cannot ask them questions, so you have to watch (their) behavior to see what they do," says de Waal, director of Emory University's Living Links Center, in his Dutch-accented voice that is both gentle and authoritative.

He adds, with dry humor: "With humans, you can ask questions and you get all sorts of answers I don't trust, so I prefer to work with chimpanzees for that reason."

Living Links is part of the oldest and largest primate center in the United States: The Yerkes National Primate Research Center, a secluded grassy area in suburban Atlanta where humans work in office trailers and other animals play in open-air compounds.

De Waal, who has been at the center for more than 20 years, has made a career out of finding links between primate and human behavior, particularly in the areas of morality and empathy.

You might think of "morality" as special for humans, but there are elements of it that are found in the animal kingdom, says de Waal -- namely, fairness and reciprocity. His latest study, published this week in the journal Proceedings of the National Academy of Sciences, suggests that chimpanzees may show some of the same sensibility about fairness that humans do.

The popular belief that the natural world is based on competition is a simplification, de Waal says. The strength of one's immune system, and the ability to find food, are also crucial. And many animals survive by cooperating.

"The struggle for life is not necessarily literally a struggle," he said. "Humans are a highly cooperative species, and we can see in our close relatives where that comes from."

Mammals such as wolves, orcas and elephants need their groups to survive, and empathy and cooperation are survival mechanisms. De Waal discusses these mechanisms in his 2009 book "The Age of Empathy: Nature's Lessons for a Kinder Society."

"We think that empathy evolved to take care of others that you need to take care of, especially, of course, between mother and offspring, which is universal in all the mammals," de Waal said.

Laboratory chimps get a new lease on life

What it means to be fair

De Waal isn't sure that his monkeys have what a philosopher would call a "concept of justice" in an intellectual sense. But the emotional reactions researchers have observed indicates that there is, at a more basic level, a sense of justice among them.

Among the questions he investigates: If an animal gets more than another, is there is a feeling that this is somehow unjust? And if one shares food with another, is there an expectation of returning the favor?

In a 2008 study, de Waal and colleagues put two capuchin monkeys side by side and gave them a simple task to complete: Giving a rock to the experimenter. They were given cucumbers as a reward for executing the task, and the monkeys obliged. But if one of the monkeys was given grapes, something interesting happened:

As observed in a popular video that de Waal showed in his TED talk, after receiving the first piece of cucumber, the capuchin monkey gives the experimenter a rock as expected. But upon seeing that the other monkey has grapes, the capuchin monkey throws the next piece of cucumber that it is given back at the researcher.

Like children, the monkeys feel they "need to get the same thing as somebody else," de Waal said.

Based on experiments such as these, de Waal came to believe that the sense of fairness observed in monkeys is egocentric. The capuchin monkeys were upset, selfishly, when they didn't get the grapes that their neighbors received. De Waal believed this model of fairness would apply to chimpanzees also. Chimpanzees are so closely related to us that they share 99% of their DNA with humans.

But the new study, which compares chimpanzees to young children, makes de Waal rethink that view.

"Now with this experiment, we are thinking that they have a higher level, where they worry about reward division in general," he said, "and it's now unclear how they differ from humans."

The new study: A human sense of fairness?

In the new study, de Waal and colleagues had chimpanzees and, separately, young children, play an "ultimatum game." This is "the gold standard of fairness for humans" because it has been played all over the world, by people in different cultures, to show that, universally, humans appear to have a sense of fairness.

Here's a video of the experiment

The basic structure of an ultimatum game is that there are rewards that can be divided between two individuals. One proposes how to divide them and the other accepts or rejects this offer. If the receiver rejects, no rewards are given out.

Human trials have shown that people usually propose a generous division of the goodies, such as half and half or 60% and 40%, de Waal said.

In the version used in the new experiment, six adult chimpanzees and 20 human children, between ages 2 and 7, participated.

The setup was such that a token could be traded for equal rewards for both partners, and a token that would give more goodies to the partner who made the choice.

In some trials, one partner proposes a reward division to the other via a token, and the receiver must accept the token in order for both parties to get rewards. In others, the partner's acceptance is not required.

The researchers found that chimpanzees and children both tended to make decisions about splitting rewards similarly to adult humans. In the situation where the responder could accept or reject the division of rewards, both chimpanzees and children tended to split the rewards with their partners. But when the partner was not given the opportunity to reject the proposal, chimps and kids tended to choose the selfish arrangement -- a token that favored the chooser.

Controversial results

So, does this mean that chimpanzees show the same sense of fairness as humans? Keith Jensen of the University of Manchester, who has conducted similar experiments in the past, isn't so sure. His results did not show that chimpanzees have a sense of fairness.

Jensen is concerned about the results of this new study because it's not clear that the responders knew that they could reject offers. None of the participants, human or chimp, ever rejected the offers of their partners.

"The fact that responders never rejected nonzero offers suggests that they were not sensitive to unfairness but were only motivated by getting food for themselves, regardless of the intentions of the proposers or the consequences for them," he said in an e-mail.

But de Waal said that responders did display negative reactions in response to some offers. Chimps would spit water and the children would say something like "You're getting more than me" in response to a selfish offer. "That indicates that they know what's going on," he said.

Jensen also criticized the design of the experiment because participants were primarily interacting with the researchers, not each other. Although one chimp had to pass a token to the other, this could be just a necessary step to get food, not a sign of agreement with the offer, he said. But de Waal stands by the study.

There are very few studies of this nature on chimpanzees compared to in humans, and more research should be done to explore the nature of the sense of fairness of human relatives.

Meet one of the oldest chimpanzees in captivity

The secret lives of primates

There's still a lot that humans don't know about their close relatives.

De Waal has made some fascinating inroads, however, including a study showing that chimpanzees can look at the behind of another chimpanzee and match it to the corresponding face, provided it's a chimp they know. This shows that the chimps have "whole-body knowledge," a concept that has not been rigorously tested in humans, he said. The research won him a 2012 Ig Nobel prize, honoring research that is both humorous and thought-provoking, shared with Jennifer Pokorny.

And he has also studied yawn contagion, the phenomenon of one person yawning in response to another person's yawn. Those who are sensitive to yawns tend to be more empathetic people, and friends and family members yawn more with each other than with strangers. This has also been shown in chimpanzees, who will yawn if another chimp they know yawns too.

But de Waal isn't sure, for instance, why three females were patrolling their compound when CNN visited in October. Males, though, have a clear purpose in patrolling: In the wild, they do it to protect their territory, de Waal said. Perhaps, he postulates, the females are mimicking the males.

Chimp males compete with each other regularly, but also come together to repair their relationships, de Waal said. This pattern of behavior is seen in human families and in the workplace -- these cycles of one-upmanship and reconciliation.

"There are many animals who are very good at cooperation, and I'm personally not convinced that we humans are necessarily best at that, but we are very good at it, that's for sure."

His next book, coming out this spring, is called "The Bonobo and the Atheist: In Search of Humanism Among the Primates," which brings together evidence that there are biological roots in human fairness and addresses the role of religion in society.

@highlight

Prominent scientist Frans de Waal studies morality in primates

@highlight

His new study suggests that chimps have a human sense of fairness

@highlight

Chimps yawn in response to other chimps yawning, just like humans, his research suggests