Fossil fuels are going to run out. This much we know. No one is entirely certain when they will run out exactly, but we know it will happen eventually.

Some estimates suggest we have about 70 years of coal, gas and oil left; the fossil fuel industry itself insists that we have significantly longer. But everyone agrees they will run out in due course.

So how will the world be powered when we can't rely anymore on fossil fuels? Why with volcanoes, waves, wet wood and solar power from space.

To compensate for the decline of traditional energy sources, researchers around the world are developing innovative new technologies that -- between them -- may provide a long-term solution to our rapidly growing energy needs. Some are familiar, some may seem far-fetched, and some could potentially pose as much of a threat to the environment as fossil fuels themselves.

CNN takes a look through some of the more interesting and unusual energy technologies currently under development.

Solar energy from space

The idea of collecting solar power from space has been under consideration since the 1970s. Putting solar panels into orbit offers a few obvious advantages over regular solar power such as not having to deal with atmospheric interventions (cloud cover and atmospheric gasses) and not losing any productivity at night.

In the past, trying to get a power plant to the edge of the Earth's atmosphere seemed deeply unlikely. But John Mankins, a former NASA engineer now with the Artemis Group has been working on a project that he believes will make such an audacious idea simple:

"The basic concept of the Solar Power Satellite (SPS) is to deploy a large platform in space near Earth," Makins says, "typically in a high orbit where the sun shines almost constantly, where it would harvest sunlight, convert it into electricity and then transmit it to receivers on Earth for use."

Read more: Can Africa unlock its solar potential?

Some have suggested that lasers could be used to transmit the energy from space. Mankins says that in his view this is possible, but potentially dangerous ("think about the Death Star" he said ominously in an interview with Motherboard). Instead his project aims to use low-intensity microwave transmitters, which he believes will be safer.

Mankins says that the energy yield from a solar power satellite could be significant, potentially delivering up to 1,000-2,000 MW of power to the Earth.

To put it into perspective, he says "a typical home in the U.S. requires about 4-5 kW of power, or about 100 kW-hours per day, or about 3,000 kW-hours per month, or about 36,000 kW-hours per year. So a single SPS ... would -- for example - deliver power / energy for roughly 240,000-480,000 homes."

Some critics say the project would be prohibitively expensive or that getting something so large into space presents challenges. Others note that the energy yield is still not high enough to make the project worthwhile. Still, the fact that it is being considered by NASA lends it significant weight. So perhaps it is not so out of this world after all.

Mining volcanoes for power

Last year, work began on a new plan to extract heat from the hot rocks that lie under and around volcanoes. By injecting water into cracks in the ground, researchers hope that they may be able to create steam to power subterranean electricity turbines.

Two companies, AltaRock Energy and Davenport Newberry, were granted permission to test this procedure in the land around the Newberry Volcano in Oregon, in a process that critics argue is not dissimilar to the controversial technique of hydraulic fracturing.

Read more: Nuclear fusion is the 'perfect energy source'

Over the past 12 months hydraulic fracturing or fracking has been the subject of protests around the world, but in fact it has been around since the 1960s. The CEO of AltaRock, Susan Petty, said in a company blog post that "creating multiple reservoirs from a single injection multiplies the amount of energy that can be extracted from each production well," and will "extend the life of the well and increase the energy recovery from each well, significantly improving the economics of enhanced geothermal system power generation."

But fracking is known to potentially generate earthquakes, and -- as noted by Wired magazine -- practicing a similar technique beneath a volcano that the U.S. Geological Survey says "is certain to erupt again" seems an odd choice.

Whether the technique can yield significant energy return, and be conducted safely is still a matter of debate as heated as the Newberry volcano itself.

Wave energy

Wave energy is already being used across the world. Billions of dollars have been invested in the technology and the world's first "wave farm" opened near Porto in Portugal in 2008. At the European Marine Energy Center in Orkney, Scotland, the world's biggest wave farm was approved for construction earlier this year. The 40MW farm off the north-west coast of Lewis promises to deliver enough energy to power nearly 30,000 homes.

Wave farms deploy massive buoys to turn the motion of waves into power. Aquamarine Power the company running the project in Orkney, says that its huge yellow buoys have "a maximum generating capacity of 800kW." The bright yellow machines measures 26 meters across and are installed at a depth of around 13 meters, around 500 meters from the shore.

The advantages of wave power are similar to those of wind -- the waves are free -- but there are some additional benefits. In particular, it's easier to forecast wave energy output, because waves are driven by wind, but don't vary as rapidly; they build up more slowly and dissipate more gradually. That makes the energy from waves more predictable than that from wind or solar, which means that it is easier to integrate into the power grid.

At present the UK is the world leader in the technology, with the U.S., Portugal and France also significant players.

Pocket particle accelerators

Researchers working in a laboratory in Daresbury, UK believe that their pint-sized particle accelerator -- like the Large Hadron Collider in Switzerland but much smaller -- could offer a genuine alternative to fossil fuels. Powered by thorium, a naturally occurring radioactive substance, the small scale collider could generate significant amounts of energy.

The Mail on Sunday estimates that just one ton of thorium could "produce as much energy as 200 tons of uranium, or 3.5 million tons of coal."

"The idea of thorium reactors is one that is under a lot of discussion these days; clearly the physics will work," says Mankins.

But he notes that there are always hazards in using nuclear material.

"Even though it certainly would be safer than past nuclear reactor approaches, it seems likely to me that governments are not going to want a lot of radioactive material on the highways."

Wet leaves and damp wood

Biomass power involves the breakdown of biological material -- such as leaves and wood -- to produce gasses like hydrogen and methane, which in turn can be burned.

The problem with some existing biomass power plants is that they need the biological materials to be dry. Jens Dall Bentzen, a Danish inventor, has come up with a new type of biomass furnace that can trap moisture from damp materials and export it as hot water. Dall Benson believes this could allow his new furnace to generate up to 30% more energy.

Read more: Solar power when the sun has set

"What's unique about biomass," says Dall Bentzen, " is that you can store it. You never really know when the wind is blowing. With biomass we have the control to use it when we need it."

"Wind is the resource we have most of in Denmark," Danish Climate and Energy Minister Martin Lindegaard told CNN, "and we need biomass and biogas to have the back up for when the wind stops blowing."

Critics argue that burning biomass contributes carbon dioxide to the atmosphere, but its proponents suggest that such damage can be offset by growing crops specifically to be burned.

A viable alternative?

One of the most substantial indicators of the viability of alternative energies can be seen in the growth in investment from venture capitalists and other private investors.

William McDowall, from the University College London Energy Institute, notes that venture capital investments in clean energy went from less than $100 million a year in the late 1990s to over $10 billion a year in 2011.

"In the year 2000, most alternative energy technologies were considered niche options that might one day show promise -- now they're multi-billion dollar industries, significant enough to precipitate serious trade disputes between the US, EU and China," McDowall says.

Government investment has shown a similar pattern, but significant public and private sector research money is still going into fossil fuels. New extraction and processing technologies for coal, oil and gas are still the main focus of private sector research and development.

However many experts, McDowall included, believe that this may change by 2025 when alternative energies could finally stop being regarded as "alternative."

@highlight

Researchers are looking for alternatives to fossil fuels

@highlight

Former NASA engineer John Mankins plans to put solar power plant into space

@highlight

UK, France, Portugal and U.S. world leaders in wave power

@highlight

Danish inventor Jens Dall Bentzen creates biomass furnace that can burn wet wood