(CNN) -- Fifty years ago, a Frenchman and a German -- seared by the devastation of World War II -- forged an enterprise with the less than exciting name of the European Coal and Steel Community.

West German Chancellor Konrad Adenauer and French Prime Minister Robert Schuman's modest beginning to European integration -- to tie together the coal and steel industries of France, West Germany and the Benelux countries -- would over the next half-century become a behemoth of 27 states, many of which didn't even exist in 1952.

That European Union vision is now at an historic crossroads and could over the next months begin to shred.

A dysfunctional legacy

The European club has both expanded in number and deepened in purpose. Beginning as a common market with expensive subsidies to farmers, it evolved into a community with coordinated foreign and trade policies, open borders among many members, a common social policy and a powerful European Court. Vast sums have been spent on infrastructure for poorer members.

Most notably, the Maastricht Treaty, named after the Dutch town where it was signed in 1992, began the process of monetary union and -- supposedly -- economic convergence among member states. The first part happened; the second did not. A "stability and growth pact" was meant to harmonize interest rates, inflation and government deficits. But there were no enforcement mechanisms beyond sharp words and a slap on the wrist. France and Germany were among the first states to breach the commandment that deficits shalt not exceed 3% of GDP.

Some critics argue that Europe is like the python that swallowed a goat. In 1990, there were 12 members of the EU; now, the 27 members span an area from Lisbon to Tallinn, from Cyprus to Stockholm.

How Europe grapples with the dysfunctional legacy of both an unbalanced deepening and headlong expansion will decide whether the eurozone recovers or withers.

The state of things now

The first hurdle to overcome is the Greek election. Should a working majority emerge under the leadership of the New Democracy Party, Greece may follow through with the next tranche of public spending cuts demanded by its "troika" of creditors: the European Commission, the International Monetary Fund and the European Central Bank. The new Greek government will expect in return help from the troika rather than the same diet of austerity, arguing that the Greek people have to be offered some incentive to endure more sacrifice.

But if political paralysis begun by May's vote continues, the uncertainty over whether Greece can remain in the eurozone will intensify.

Even if a weak pro-bailout government is formed, Greece is already behind on its obligations to privatize state industries and improve tax receipts. For Greeks, tax evasion is a national sport; the government is owed nearly 50 billion euros in back taxes. Greek media suggest depositors have withdrawn up to 5 billion euros from local banks in the past two weeks.

Uncertainty in Greece would in turn intensify the pressure on Spain and Italy, amid doubts about the whole eurozone enterprise. The combined economies of Ireland, Portugal and Greece -- the three countries that have been bailed out -- are smaller than that of Spain, which has quickly been dubbed "too big to bail, too big to fail." The European Union's willingness to help bail out Spain's massively indebted banking system to the tune of 100 billion euros ($125 billion) produced a "relief rally" on the bond and stock markets, but the relief scarcely lasted 24 hours.

By the end of last week, the yield on Spain's 10-year bond hovered around 7%, the financial equivalent of being admitted to intensive care with a raging fever. The new Spanish government has resisted a full bailout, arguing that it has undertaken drastic economic reform and that government finances (not too awful) should not be confused with the banks' (dreadful). But the influential ratings agencies do see a link; Moody's has cut Spanish sovereign debt to just a notch above junk status, on a par with Azerbaijan. Unemployment is at record highs, especially among the young; house prices are collapsing.

The Italians are also getting fed up with austerity, as Prime Minister Mario Monti acknowledged in a recent interview with CNN's Christiane Amanpour. He has joined the "growth club" with new French President Francois Hollande but has precious little room for maneuver, as the price on Italian debt has also risen. The IMF has praised Monti's efforts to sort out Italy's public finances but says deregulation and labor reform require further effort, just as the Italian economy is forecast to shrink 2% this year.

From outside the eurozone, its partners look on with horror. The governor of the Bank of England, Mervyn King, said last month, "Our biggest trading partner is tearing itself apart with no obvious solution."

What will be Europe's future?

Going forward (and, admittedly, simplifying the scenarios), Europe is looking at three paths, according to political and financial analysts.

The first and most traumatic is a disorderly collapse of the eurozone, starting in Greece but spreading to Spain and Italy. This scenario begins with anything less than a clear victory for the "bailout" parties in Greece, followed by the virtual implosion of the Greek state, whose coffers are nearly empty. The current economy minister says Greece has enough money to survive until July 15.

In this scenario, Germany opts to puts fiscal rectitude ahead of its pan-European principles. Many Germans are already thinking this way. Deputy Finance Minister Steffen Kampeter told the BBC on Thursday that debt was a "national responsibility."

"I don't see any strategies where we socialize and redistribute the bad political decisions made by some who are over-indebted," he said.

Germany has ruled out the introduction of eurobonds, which would essentially dilute its credit rating to the advantage of the peripheral economies. And German Chancellor Angela Merkel has warned that Germany's role in saving the eurozone is "not unlimited."

"We must all resist the temptation to finance growth again through new debt," she said.

Taken to its logical conclusion, this first scenario could reduce the eurozone to a Franco-German core, with the smaller Benelux states attached. The consequences for the European economy would be calamitous, with governments defaulting on debt, capital controls imposed to prevent money from fleeing states on the verge of falling out of the eurozone and the likelihood of prolonged recession across Europe.

In addition, the very process of reverting to national currencies (for which there is no road map) would throw up a multitude of legal and contractual nightmares. And politically, the idea of European union would be set back decades.

The second course is that Europe muddles through while continuing to grope toward banking and fiscal integration.

A compromise between Greece and the troika (not so unlikely, given that 80% of Greeks want to stay in the eurozone) would bring the country back from the edge of the abyss, though any meaningful recovery would be years away.

The new European Stability Mechanism, due to come into effect next month as a permanent rescue fund, would recapitalize banks and help cool yields on vulnerable sovereign debt (Spain, Italy, Cyprus). Its war chest of 500 billion euros would be bolstered as required. (French officials are already suggesting that it be allowed to borrow from the European Central Bank.)

Merkel would make token concessions to the "growth agenda" at the European summit in Brussels at the end of this month.

Moves toward a banking union that would insure deposits, progress toward common tax policies, the decline of government debt and the emergence of the eurozone from recession would ease the pressure on governments struggling to find common ground. Merkel has acknowledged that this is a "Herculean task," but it is in Germany's interest. Very nearly 60% of German exports stay inside Europe, and are competitive because they are priced in euros rather than deutsche marks. A collapse of the eurozone would savage the German economy.

Merkel has signaled her support for tougher European supervision of the eurozone banking industry, in an implicit criticism of the way the authorities in Madrid underestimated the plight of Spanish banks. That seems an important precondition for further German support.

Next year, Merkel faces an electorate already impatient with German largesse for little return. Until then, the argument goes, she can't afford to be seen to be generous.

The third course would see a daring leap toward much closer integration: the "economic convergence" promised by Maastricht but never realized as governments allowed debt to rise and failed to liberalize their labor markets, supervise their banks or harmonize their tax systems. This is the mantra of Hollande, who wants measures to stimulate growth and "imagination and creativity" to deepen financial union, such as a joint fund to pay down debt.

There seems little prospect that such sudden and dramatic initiatives will gain the support of a European public no longer convinced of the benefits of deeper integration, nor of a German state unwilling to allow co-signers on its checking account.

Last week, Adenauer's grandson, Stephan Werhahn, said that his grandfather and Schuman "wanted to build a strong and independent Europe, but now with the bailout funds and billions in rescues, we are demolishing it." And he announced that he was leaving the party his grandfather had founded.

The counter-argument of history is that the European banking crisis of 1931 "contributed directly to the breakdown of democracy" in Germany and across the continent, according to economists Niall Ferguson and Nouriel Roubini.

Writing in the Financial Times recently, they concluded, "The EU was created to avoid repeating the disasters of the 1930s. It is time Europe's leaders -- and especially Germany's -- understood how perilously close they are to doing just that."

@highlight

A dysfunctional legacy hampers current eurozone woes

@highlight

Greece will be key in determining Europe's future

@highlight

Possible scenarios include collapse or even a closer integration