Washington (CNN) -- Inside the marble walls at the Supreme Court, the last days of June are called the "flood season," a frantic push to finish its work for the summer. The stakes are especially high this term, with rulings on two major issues left to be announced.

What the justices decide in the next week or so could fundamentally change lives and legacies on a range of politically explosive issues.

On Monday, the court sidestepped a sweeping decision on the use of race-conscious school admission policies, ruling on the criteria at the University of Texas and whether they violate the equal protection rights of some white applicants. The justices threw the case back to the lower courts for further review.

That leaves two high-profile issues with rulings still to be announced:

-- Same-sex marriage: A pair of appeals testing whether gays and lesbian couples have a fundamental constitutional right to wed.

-- Voting rights: The future of the Voting Rights Act, and continued federal oversight of elections in states with a past history of discrimination.

"It's almost unimaginable the number of things that the Supreme Court is going to decide that will affect all Americans," said Thomas Goldstein, a top Washington attorney and publisher of SCOTUSblog.com.

"What would surprise me this term is if the court upheld ... the (enforcement tool behind the) Voting Rights Act. And I think it would be a big surprise if the court did anything radical when it came to same-sex marriage -- either saying there was a constitutional right to it, or rejecting that claim outright and forever. I think that's something they're going to try and tread that middle ground path."

The court will not say precisely when these hot-button opinions will be released, but it could wrap its work by Thursday. Depending on how long it takes the justices to finish up, that internal deadline might slide into early July.

Veterans of forgotten voting war count the cost

Oral arguments have ended for the term, and the justices have already secretly voted on the pending cases. Individual justices have been assigned to write one or more opinions, as well as separate dissents. Only they and their law clerks know how this will end.

And no one is talking -- continuing an unbroken tradition of discretion rare in leak-loving Washington.

"At the Supreme Court, those who know, don't talk. And those who talk, don't know," Justice Ruth Bader Ginsburg has said, echoing similar comments from her colleagues.

The high court holds fast to an unofficial but self-imposed deadline to have all draft opinions finished by June 1. They are circulated to colleagues, and subsequent dissents and concurrences must be submitted by June 15. Nothing is final until the decision is released to the public. Votes can and do change at the last minute.

Justices and their law clerks are holed up in chambers, working overtime to frame and craft the final opinions, making sure every fact, every footnote, every legal theory is fully checked and articulated.

The nine members know they are writing their legacies with these issues. The outcome may be disputed, but the constitutional reasoning -- at least in the justices' own minds -- must be sound.

"Getting themselves organized, identifying the different majorities, getting opinions written and circulated in dissents and concurrencies will really test their capabilities in the final days," Goldstein said.

The opinion-writing exercise is little-known, and the court likes it that way. Predicting the outcome is a time-honored Washington parlor game, but rarely consistently successful.

There has been particularly intense focus on the same-sex marriage cases. Thousands of activists rallied at the court when the case was argued in March.

Fast facts: Top U.S. Supreme Court decisions

At issue:

-- Federal benefits. The Defense of Marriage Act, or DOMA, is a 1996 law saying that, for federal purposes, marriage is defined as only between one man and one woman. That means federal tax, Social Security, pension, and bankruptcy benefits, family medical leave protections -- and a thousand more such provisions -- do not apply to gay and lesbian couples. Edie Windsor, an 84-year-old New York woman, is the key plaintiff in the DOMA fight. She was forced to pay more than $363,000 in extra estate taxes after the death of her longtime spouse, Thea Spyer.

-- State referendums. The California high court had earlier concluded same-sex marriage is legal, but the 2008 voter-approved Proposition 8 abolished it. The U.S. Supreme Court is being asked to establish same-sex marriage as a constitutional right, but it could instead decide a more narrow question: whether a state, through referendum, can revoke that right once it has been recognized.

The political, social, and legal stakes of this long-simmering debate will once again put the high court at the center of national attention, as it was in last summer's ruling upholding most of the massive health care reform law championed by President Barack Obama.

Nine states now allow gays and lesbians to legally wed: Connecticut, Iowa, Maine, Maryland, Massachusetts, New Hampshire, New York, Vermont, and Washington, as well as the District of Columbia. Delaware, Rhode Island and Minnesota recently passed laws that take effect this summer.

It is estimated about 120,000 legally married gay and lesbian couples live in the United States.

Opinion: Bring voting into the digital age

There is division within the ranks of both sides about whether the court will -- and should -- issue a sweeping ruling on the constitutional "equal protection" question. Some activists and politicians -- even some justices themselves -- think the elected branches may be in a better position to drive the same-sex marriage issue, not the courts.

Voters in three states last November approved same-sex marriage, marking the first time the ballot was used to approve such unions. California is the only state to allow and then revoke same-sex marriage.

"This is a conservative court -- conservative ideologically and conservative in the sense that they like to take baby steps, and it seems very unlikely that they would make some big radical move requiring all states to recognize same-sex marriages," Goldstein said. "They are much more likely to do something a little more modest. The other thing about them is that they don't want to be on the wrong side of history. It seems pretty clear where this is going, with a much broader recognition of same-sex marriage, and so the justices don't want to call that into question when the country is headed in that direction."

In fact, the court has set itself up to "punt" on both Proposition 8 and DOMA, avoiding for now consideration of the constitutional questions.

Such a "legal letdown" could turn on "standing," or the legal authority or eligibility of those involved in the lawsuit to argue the case. California's governor has refused to defend Proposition 8 in court, leaving a coalition of private groups to step in. Can they satisfy court scrutiny by establishing they would suffer tangible harm if the lower court ruling stands?

The justices could also "DIG" it, that is, have the case "dismissed as improvidently granted." Basically, the justices would be saying they should not have taken the Proposition 8 appeal in the first place.

Justice Sonia Sotomayor at the March oral argument suggested as much: "If the issue is letting the states experiment and letting the society have more time to figure out its direction, why is taking a case now the answer?" Some of her conservative colleagues seemed to agree as well.

The difference between rejecting the case on standing or DIG grounds would be important. A DIG would be likely to mean lower court rulings striking down Proposition 8 would hold, allowing California gay and lesbian couples to marry if they chose. How quickly that would happen is unclear because further legal challenges could be filed.

But a "standing" ruling would likely nullify everything, perhaps forcing both sides to start all over again in the lower courts, and limiting the reach of gay marriage to perhaps only a few California counties. Another statewide referendum, likely to be held next year, could finally settle the matter. Recent polls show growing support for same-sex marriage in California, reflecting a trend nationwide.

Scenarios, terminology key in prepping for same-sex court ruling

DOMA has its own sticky procedural questions. Obama now supports gay marriage, and has refused to defend the 1996 federal law. That has left House Republicans as the official parties in support of DOMA.

So the court could also dismiss that case on standing grounds. Most legal analysts, however, expect a more substantive ruling, one based on DOMA's merits.

Picking winners and losers at this stage is a subjective, even partisan, exercise. The court itself will be both cheered and vilified however it rules. But as an institution, it has survived similar crises of confidence over its discretionary authority in rulings involving slavery, racial integration, corporate power, abortion -- even Bush v. Gore.

Reaction to these big cases will be swift and furious from the professional punditry and halls of government. Some individual Americans stand to gain from the decisions, while others could be hurt financially and emotionally.

All of this is entrusted in the hands of nine judges. The Supreme Court usually gets the last word in these matters, regardless of who disagrees with the decisions.

Justice Robert Jackson, on the court from 1941 to 1954, put it this way: "We are not final because we are infallible, but we are infallible only because we are final."

@highlight

Rulings on two major issues are among those remaining to be announced

@highlight

The cases include a pair of appeals testing the right to same-sex marriage

@highlight

Two other cases involve the future of the Voting Rights Act and oversight of some elections

@highlight

The justices have already secretly voted on the pending cases