(CNN) -- A month after a devastating earthquake sent a wall of water across the Japanese landscape, the global terrain of the atomic power industry has been forever altered.

The ongoing drama at the power plant in Fukushima -- a name now ranked alongside Three Mile Island and Chernobyl as history's worst nuclear accidents -- has erased the momentum the nuclear industry has seen in recent years.

The growth in the emerging world, such as China and India, fueled increased demand in planned reactors. Oil-rich regions like the United Arab Emirates and smaller nations like Vietnam announced plans to build nuclear reactors in the past year. Once the bane of environmentalists, the nuclear industry enjoyed newfound "green" credentials as a cleaner alternative to coal-fired plants that belch greenhouse gases to produce electricity.

Before Fukushima, a "nuclear renaissance" -- as it was termed in the press -- seemed well underway, except for this point: Nuclear power, as a total of world energy supply, has been in steady decline for the past decade.

From 2000 to 2008, nuclear energy dropped from 16.7% to 13.5% of global energy production, according to the World Nuclear Industry Status Report 2009. The 2010-11 preliminary report, expected to be released Wednesday, will show the downward trend has continued, according to study author Mycle Schneider. While nuclear energy production has steadily increased, its piece of the global electricity pie is shrinking compared to traditional sources such as coal and alternatives like wind and solar power.

"This doesn't indicate there is a nuclear revival," said Brahma Chellaney, one of the architects of India's atomic strategy and a fellow at the Centre for Policy Research in New Delhi. "Had Fukushima happened two years later, the renaissance may have been underway. But if (the nuclear industry) was hoping for a real revival, you can safely say this won't happen now."

Political fallout

The shockwaves from the Fukushima plant disaster shook German politics, which could have economic implications far beyond the nuclear industry as Germany -- the largest economy in Europe -- attempts to steer the eurozone out of its debt crisis. Chancellor Angela Merkel's Christian Democrats suffered a historic loss to the Green Party during a key state election in Baden-Württemberg, a traditional stronghold for Merkel's party.

The elections came two weeks after the Japan disaster and the defeat was attributed in large part to nuclear fears in the wake of Fukushima and Merkel's pro-nuclear credentials. (Merkel temporarily shut down seven of the nation's 17 reactors and talked about an "exit strategy" from nuclear power in the week between the Japan temblor and the state elections; critics accused Merkel of flip-flopping to reflect a shift in opinion away from nuclear power.)

The political hot potato playing out in Germany can be expected elsewhere as aging reactors come up for extension of licenses or replacement in the U.S., the UK and Japan. The average age of the world's 443 nuclear reactors is 25 years, according to the World Nuclear Industry Status Report.

"In the next 10 years, nuclear power will face enormous public pressure in large democracies like the U.S. and India," said Chellaney, a nuclear energy proponent.

China, by far, has the largest number of plants planned with 27 reactors currently under construction, followed by 11 in Russia, and five apiece in India and South Korea, according to the International Atomic Energy Agency (IAEA). Beijing announced that China would temporarily suspend construction of new plants pending review of the Fukushima incident, but few analysts believe China will scuttle planned reactors.

"The countries that are going to do big builds ... have said loudly and clearly, we are not backing down from nuclear energy," said Margaret Harding of the American Nuclear Society, a group for nuclear industry professionals.

Fear factor

Nuclear power has had an uphill climb in public perception since the 1945 explosions over Hiroshima and Nagasaki at the end of World War II first put the word "atomic" onto headlines across the globe.

"Radiation in particular is a scary thing -- we can't see, we can't touch it, you can't look at the ground and know its there," said Harding, a former vice president of engineering at GE Nuclear Energy who now advises companies on nuclear industry issues.

"(Nuclear power) gets conflated in people's minds with weapons," Harding said. "The fact that the first controlled nuclear plants were to run submarines and other military secrets, there is a web of secrecy as to what you can talk about, which adds to the mystique."

While the devastation in Fukushima is "horrible," Harding and other nuclear proponents argue that nuclear crises aren't being judged by the same yardstick as other -- and statistically more deadly -- industrial disasters. "Look at Bhopal: thousands of people died there -- did people walk away from chemical engineering?" said Harding, referring to the 1984 Union Carbide chemical plant disaster in India.

There were no deaths at the 1979 Three Mile Island crisis in the U.S. A 2005 report from the World Health Organization said as many as 4,000 people may die of radiation exposure from the 1986 Chernobyl disaster in Russia, although fewer than 50 deaths were directly attributed to the disaster.

"The numbers don't lie, coal kills millions every year" through air pollution, said Michael Shellenberger, head of the Breakthrough Institute, a think tank that aims to modernize liberal thought, at Fortune's Brainstorm Green conference last week in California.

Green nukes

When Harding moved to California in 1981, the young nuclear engineer attended a meeting of the Sierra Club, the environmental group. "When they found out what I did, they kicked me out," Harding recalled.

In the past decade, however, many environmentalists have embraced nuclear power as a better alternative than coal and gas-fired plants to reduce greenhouse gas emissions. France, for example, gets 75% of its power from nuclear plants -- the highest ratio in the world, according to the IAEA. By comparison, the U.S. gets just under 20% of its power from nuclear, although it has the most reactors in operation -- 104 reactors, nearly double the number in France.

"France's advance in terms of nuclear and hydraulic energy generation (allows) the country to maintain its emissions at the same level as they were in 1990," said Sabine Mezard, a spokesperson for French energy giant EDF.

Still, the early promise of nuclear energy as a cheap, clean form of energy has never materialized. Costs of nuclear power plants can be as high as $10 billion, according to a 2010 report by the CIGI Nuclear Energy Futures Project at Carleton University in Canada. The average construction time is seven years, but with licensing approval new builds often take a decade, Schneider said.

What's the alternative?

Alternative energy production is faster and cheaper, Schneider said. "In the U.S. in 2004, 2% of all new power produced that year came from alternative energy sources ... by 2009, 55% of all new power was from alternatives," Schneider said. "There's no way nuclear could add that much, that fast."

Nuclear power reactors are dependent on government subsidies and loan guarantees to be built, cover costs in case of accidents and assume long-term responsibility for storage of spent radioactive fuel, critics say, which artificially lowers the cost of production.

"These plants are 30-year investments -- it's hard to get the market interested in more than two-year investments, and loan guarantees are not a subsidy," countered Harding of the American Nuclear Society. Government backing of insurance in case of disasters has resulted because "the nuclear industry has had so few accidents, there is no actuarial for insurance companies on which to offer an insurance policy," she added.

Market reaction has been swift against the nuclear industry after the Fukushima disaster. Companies on the Standard & Poor's Clean Energy Index rose on average 17% in the wake of the disaster, while companies on the S&P Nuclear Index fell 8.7%. "We expect a number of impacts from the public and political backlash against nuclear, which could mean the focus switches to renewables," an HSBC report said in March.

Still, no one expects the industry to fade. The U.S., Japan, South Korea, Russia and France have significant nuclear industries with important strategic as well as economic interests, analysts say.

"No one is going to walk away," Harding said. "If the U.S. wants to be a leader in this technology, they've got to be playing in this technology."

@highlight

Nuclear power dropped from 16.7% to 13.5% of global energy from 2000 to 2008

@highlight

Firms on the S&P Nuclear Index fell 8.7% after the disaster; renewables rose 17%

@highlight

EDF: 75% of French power is nuclear, keeping carbon emissions to 1990 levels

@highlight

Analysts: Public backlash against nuclear energy expected to see push for alternatives