What is widely recognized as the most authoritative study of the United States' responses to mass killings around the world -- from the massacres of  Armenians by the Turks a century ago, to the Holocaust, to the more recent Serbian atrocities against Bosnian Muslims and the ethnic cleansing of the Tutsis in Rwanda -- concluded that they all shared unfortunate commonalities:

"Despite graphic media coverage, American policymakers, journalists and citizens are extremely slow to muster the imagination needed to reckon with evil. Ahead of the killings, they assume rational actors will not inflict seemingly gratuitous violence. They trust in good-faith negotiations and traditional diplomacy. Once the killings start, they assume that civilians who keep their head down will be left alone. They urge cease-fires and donate humanitarian aid."

This is an almost perfect description of how the United States has acted over the past two years as it has tried to come up with some kind of policy to end the Assad regime's brutal war on its own people in Syria.

The author who wrote the scathingly critical history of how the United States has generally dithered in the face of genocide and mass killings went on to win a 2003 Pulitzer Prize for her book "A Problem from Hell:  America and the Age of Genocide."

A decade after winning the Pulitzer, that author is now the U.S. ambassador to the United Nations. Her name, of course, is Samantha Power, and she is a longtime, close aide to President Barack Obama. She started working for Obama when he was a largely unknown junior senator from Illinois.

Power called her 610-page study of genocide "A Problem from Hell" because that's how then-U.S. Secretary of State Warren Christopher referred to the Bosnian civil war and the unpalatable options available to the U.S. in the early 1990s to halt the atrocities by the Serbs.

One of the U.S. officials that Power took to task in her book is Susan Rice who, as the senior State Department official responsible for Africa, did nothing in the face of the genocide unfolding in Rwanda in 1994.

Rice is quoted in the book as suggesting during an interagency conference call that the public use of the word "genocide" to describe what was then going on in Rwanda while doing nothing to prevent it would be unwise and might negatively affect the Democratic Party in upcoming congressional elections.

Rice later told Power she could not recall making this statement but also conceded that if she had made it, the statement was "completely inappropriate, as well as irrelevant."

Rice is now Obama's national security adviser.

In 2012, at Power's urging, Obama announced the creation of an interagency task force to help stamp out atrocities around the world. Called the Atrocities Prevention Board, it was led by Power during its first year. Meanwhile, the body count in Syria kept spiraling upward.

For the past two years, Obama hasn't wanted to intervene militarily in Syria.

Who would? The country is de facto breaking up into jihadist-run "emirates" and Alawite rump states. It is also the scene of a proxy war that pits al Qaeda affiliates backed by Qatar and Saudi Arabia against Hezbollah, backed by Iran.

Whoever ultimately prevails in this fight is hardly going to be an ally of the U.S. It's an ungodly mess that makes even Iraq in 2006 look good.

It is, in short, a problem from hell.

Power, Rice and Obama today face some of the very same unpalatable choices that have confronted other U.S. national security officials as they tried to prevent mass killings in other distant, war-torn countries.

They can continue to do little as the Syrian civil war drags on into its third year with 100,000 dead and rising. It's a state of affairs now compounded by the fact that the regime of President Bashar al-Assad appears not only to have crossed the "red line" with its use of chemical weapons but seems to have now sprinted past that line, killing hundreds with neurotoxins in a Damascus suburb, according to U.S. Secretary of State John Kerry. He's blasted those attacks as something that "should shock the conscience of the world. It defies any code of morality."

Opinion: How Al-Assad used chemical weapons to poison debate on Syria

Doing nothing will not be treated kindly by future historians writing in the same vein as Power.

The issue now in Syria is not simply that al-Assad is massacring his own civilians at an industrial rate, but he is also flagrantly flouting a well-established international norm by this regime's reported large-scale use of neurotoxins as weapons against civilians. It seems inconceivable that the United States as the guarantor of international order would not respond to this in some manner.

But on what authority? There is scant chance of a U.N. resolution authorizing military action. When she was U.N. ambassador, Rice skillfully ushered a resolution through the Security Council that authorized military action in Libya in 2011. But Russia and China will almost certainly veto any similar kind of resolution on Syria.

Russia is one of Syria's few allies, and Russia and China are generally staunchly against any kind of international intervention in the affairs of other countries, no matter how egregious the behavior of those states might be.

That leaves the possibility of some kind of unilateral action by the United States.

The U.S. regularly infringes the sovereignty of countries such as Pakistan and Yemen with CIA drone strikes on the novel legal theory that terrorists planning strikes on the U.S. are living in those nations and those countries are either unable or unwilling to take out the terrorists on their territory -- and therefore their sovereignty can be infringed by drone attacks.

But making a claim that the Syrian regime threatens the U.S. is implausible, and therefore some kind of unilateral American action seems quite unlikely.

In 1986, the Reagan administration launched air strikes at the homes of Libyan dictator Moammar Gadhafi, but only after an incident in which Libyan agents had bombed a disco in Berlin, killing two American servicemen. No such casus belli exists with Syria today.

Since neither a U.N. authorized military mission nor a unilateral American strike seem likely, what options are left?

One appealing option could be something along the lines of the Kosovo model. The Kosovo War in 1999 was entirely an air war in which no American soldiers were killed. The goal of the air campaign was to push Serbian forces out of Kosovo. Russia was allied with the Serbs so, as in the Syrian case today, there was no chance a U.N. resolution authorizing force would pass.

At the time NATO justified the Kosovo War "to avert a humanitarian catastrophe."

On Thursday, the British government released a similar statement saying that the grounds for military action against Syria "would be humanitarian intervention; the aim is to relieve humanitarian suffering by deterring or disrupting the further use of chemical weapons."

But on Thursday night the British parliament voted against authorizing military action--a real setback for the Obama administration's plan to assemble something of a coalition to participate in any forthcoming operation in Syria.

In the case of Kosovo, the war was conducted by NATO forces.  Kosovo is, of course, in Europe, and NATO is a Europe-focused security alliance while Syria is the Middle East, so NATO action there would be much more problematic.

(A NATO force does fight in Afghanistan today, but that is only because one of its member states, the United States, was attacked on 9/11 from Afghanistan by al Qaeda, which triggered NATO's Article 5, the right to collective self-defense of the members of the alliance.)

If an air war were to be launched against Syria, one scenario could be that Turkey, a member of NATO, could invoke Article 5 because Syria has fired into its territory on a regular basis.

So far, Turkey has proved reluctant to invoke Article 5 but the reported large-scale use of chemical weapons by the Assad regime might change the calculus of the Turks.

A further source of legitimacy for military action could be the strong statement Tuesday by the Arab League that the Assad regime is responsible for  the "heinous crime" of using chemical weapons. The Arab League is generally a toothless talking shop, which seemed to have surprised even itself two years back when it endorsed military action against Gadhafi. However, the Arab League has not endorsed any military action against Assad, although some of its members have privately urged the U.S. to take action against his regime in the past.

It is hard to believe that some kind of military action against Syria won't now take place, likely in the form of U.S. cruise missile attacks from ships in the Mediterranean.

Such attacks have the merit that they won't put U.S. aircraft at risk, which could well encounter problems with Syria's reputedly formidable air defense systems.  And the operation will likely have participation by France and a tacit green light from leading members of the Arab League such as Saudi Arabia, giving it a semblance of international legitimacy.

@highlight

Samantha Power's Pulitzer-Prize winning study found U.S. very slow to fight evil regimes

@highlight

Peter Bergen: Her work is a perfect description of U.S. dithering on the Syria crisis

@highlight

U.S. is likely to strike Syria but lacks a strong basis in international law, he says

@highlight

Bergen: U.N. won't support a strike, but NATO and Arab League could back it