The emerging process of 3-D printing, which uses computer-created digital models to create real-world objects, has produced everything from toys to jewelry to food.

Soon, however, 3-D printers may be spitting out something far more complex, and controversial: human organs.

For years now, medical researchers have been reproducing human cells in laboratories by hand to create blood vessels, urine tubes, skin tissue and other living body parts. But engineering full organs, with their complicated cell structures, is much more difficult.

Enter 3-D printers, which because of their precise process can reproduce the vascular systems required to make organs viable. Scientists are already using the machines to print tiny strips of organ tissue. And while printing whole human organs for surgical transplants is still years away, the technology is rapidly developing.

"The mechanical process isn't all that complicated. The tricky part is the materials, which are biological in nature," said Mike Titsch, editor-in-chief of 3D Printer World, which covers the industry. "It isn't like 3-D printing plastic or metal. Plastic doesn't die if you leave it sitting on an open-air shelf at room temperature for too long."

The idea of printing a human kidney or liver in a lab may seem incomprehensible, even creepy. But to many scientists in the field, bioprinting holds great promise. Authentic printed organs could be used for drug or vaccine testing, freeing researchers from less accurate methods such as tests on animals or on synthetic models.

Then there's the hope that 3-D printers could someday produce much-needed organs for transplants. Americans are living longer, and as we get deeper into old age our organs are failing more. Some 18 people die in the United States each day waiting in vain for transplants because of a shortage of donated organs -- a problem that Anthony Atala, director of the Wake Forest Institute for Regenerative Medicine and a pioneer in bioprinting, calls "a major health crisis."

An 'exciting new area of medicine'

Bioprinting works like this: Scientists harvest human cells from biopsies or stem cells, then allow them to multiply in a petri dish. The resulting mixture, a sort of biological ink, is fed into a 3-D printer, which is programmed to arrange different cell types, along with other materials, into a precise three-dimensional shape. Doctors hope that when placed in the body, these 3-D-printed cells will integrate with existing tissues.

The process already is seeing some success. Last year a 2-year-old girl in Illinois, born without a trachea, received a windpipe built with her own stem cells. The U.S. government has funded a university-led "body on a chip" project that prints tissue samples that mimic the functions of the heart, liver, lungs and other organs. The samples are placed on a microchip and connected with a blood substitute to keep the cells alive, allowing doctors to test specific treatments and monitor their effectiveness.

"This is an exciting new area of medicine. It has the potential for being a very important breakthrough," said Dr. Jorge Rakela, a gastroenterologist at the Mayo Clinic in Phoenix and a member of the American Liver Foundation's medical advisory committee.

"Three-D printing allows you to be closer to what is happening in real life, where you have multiple layers of cells," he said. With current 2-D models, "if you grow more than one or two layers, the cells at the bottom suffocate from lack of oxygen."

To accelerate the development of bioprinted organs, a Virginia foundation that supports regenerative medicine research announced in December it will award a $1 million prize for the first organization to print a fully functioning liver.

One early contender for the prize is Organovo, a California start-up that has been a leader in bioprinting human body parts for commercial purposes. Using cells from donated tissue or stem cells, Organovo is developing what it hopes will be authentic models of human organs, primarily livers, for drug testing.

The company has printed strips of human liver tissue in its labs, although they are still very small: four by four by one millimeter, or about one-fourth the size of a dime. Each strip takes about 45 minutes to print, and it takes another two days for the cells to grow and mature, said Organovo CEO Keith Murphy. The models can then survive for about 40 days.

Organovo has also built models of human kidneys, bone, cartilage, muscle, blood vessels and lung tissue, he said.

"Basically what it allows you to do is build tissue the way you assemble something with Legos," Murphy said. "So you can put the right cells in the right places. You can't just pour them into a mold."

Ethical concerns

Not everyone is comfortable with this bold new future of lab-built body parts, however.

A research director at Gartner Inc., the information-technology research and advisory firm, believes 3-D bioprinting is advancing so quickly that it will spark a major ethical debate by 2016.

"Three-D bioprinting facilities with the ability to print human organs and tissue will advance far faster than general understanding and acceptance of the ramifications of this technology," Pete Basiliere said in a recent report.

"These initiatives are well-intentioned, but raise a number of questions that remain unanswered," Basiliere added. "What happens when complex 'enhanced' organs involving nonhuman cells are made? Who will control the ability to produce them? Who will ensure the quality of the resulting organs?"

Bioprinted organs are also likely to be expensive, which could put them out of reach of all but the wealthiest patients.

Murphy said Organovo only uses human cells in creating tissues, and doesn't see any ethical problems with what his company is doing.

"People used to worry about doing research on cadavers ... and that dissipated very quickly," he said. "We don't think there's any controversy if you're producing good data and helping people with health conditions."

Most experts, including Wake Forest's Atala, don't think we'll see complex 3-D-printed organs, suitable for transplants, for years if not decades. Instead, they believe the next step will be printing strips of tissue, or patches, that could be used to repair livers and other damaged organs.

"We are very eager to put pieces of tissue to work for surgical transplants," said Organovo's Murphy, who hopes his company will be ready to begin clinical trials within five years.

Of course, any use of 3-D-printed tissue in surgical procedures would require approval by the U.S. Food and Drug Administration. That review process could take up to a decade.

By then, the notion of a surgeon putting a 3-D-printed kidney into a patient may not seem so bizarre. Then again, this swiftly evolving technology may create new moral conundrums.

"The ethical questions are bound to be the same concerns we have seen in the past.  Many major medical breakthroughs have suffered moral resistance, from organ transplants to stem cells," said Titsch of 3D Printer World.

"Will only the rich be able to afford it?  Are we playing God?  In the end, saving lives tends to trump all objections."

@highlight

3-D printers may someday be producing complex -- and controversial -- human organs

@highlight

Their precise process can reproduce vascular systems required to make organs viable

@highlight

Doctor: "It has the potential for being a very important breakthrough"

@highlight

Researcher: Bioprinting will spark a major ethical debate by 2016