Like other branches of science, nutrition is constantly evolving. As researchers learn more about vitamins and minerals, for example, dietary advice changes.

Coffee is the top source of antioxidants in an American diet.

Take vitamin D, the "sunshine" vitamin, so named because it is produced primarily in the skin through a chemical reaction that requires ultraviolet light. Increasingly, nutritionists recommend that you boost your daily intake because of vitamin D's potential to help fight certain types of cancer. In fact, many expect the next version of the Dietary Guidelines for Americans, due in 2010, to raise the amount currently recommended from 200 International Units (IU) for adults to 400 or more. But any advice that encourages exposure to sunlight concerns dermatologists, since rates of basal cell carcinoma, the most common type of skin cancer, have tripled in the past 30 years.

So . . . to D or not to D? We went to the experts for help in sorting out what the science really says about vitamin D and three other nutritional riddles, and more importantly, what that means for you.

Vitamin D

The good news: A short stroll in the sun supplies enough vitamin D to maintain healthy bones; emerging research points to strong anti-cancer benefits, too.

The potential risk: Exposure to sunlight causes skin cancer.

What the research says: Vitamin D tells the body to absorb more bone-building calcium from foods.

"Vitamin D is most known for its beneficial effects on the skeleton, but, to me, its effects on cancer are much more significant," says Bruce W. Hollis, Ph.D., professor of pediatrics at the Medical University of South Carolina in Charleston.

In a study of 47,800 men, scientists at the Harvard School of Public Health reported that 1,500 IU daily of vitamin D reduced the risk of cancers of the digestive system by 43 percent. Another study from the University of California at San Diego of 1,760 women suggests that 2,700 IU daily may reduce the risk of breast cancer by 50 percent. CookingLight.com: Power up your plate

Reaching the amount of D currently recommended --200 IU per day for adults ages 19 to 50 and 400 IU per day for those ages 51 to 70 -- through diet is difficult, Hollis says. Food sources of vitamin D are scarce; salmon, mackerel, and sardines are the top sources, containing 250 to 360 IU per 3-ounce serving. Milk comes next, but the levels of vitamin D with which it is fortified varies. When researchers from Boston University analyzed 79 milk samples, they found that 37 percent contained less than 5 percent of the 100 IU vitamin D per cup promised.

What you should do: "The most powerful source of vitamin D is the sun," Hollis says. Make the most of it. Protect your face, ears, neck, and the backs of hands each day with a moisturizer that contains a sun-protection factor (SPF) of 15 or higher. These spots are where skin cancers usually develop first. But on days when you aren't going to spend much time in the sun, leave spf off legs and arms to let them manufacture vitamin D. In just 10 minutes, a light-skinned person produces 10,000 to 20,000 IU vitamin D.

Because skin pigments can interfere with vitamin D synthesis, darker-skinned people produce it more slowly. If you have dark skin or live or work where you are seldom exposed to sunlight, talk to your doctor about supplementing your intake of vitamin D. Hollis recommends choosing a supplement that contains vitamin D3, also known as cholecalciferol; it's the vitamin's most readily absorbable form.

Coffee

The good news: Caffeine, obtained most frequently from coffee in a typical American diet, may reduce the risk of developing Parkinson's disease. An antioxidant in coffee may also help protect against diabetes.

The potential risk: Caffeine may cause bone loss, which increases the risk for osteoporosis.

What the research says: In trying to solve this nutritional conundrum, it helps to put study findings in their proper context, says Tara Coghlin-Dickson, M.S., R.D., a clinical dietitian at Stanford University Hospital in Stanford, California. A widely reported 2001 study of 489 postmenopausal women found that caffeine intakes higher than 300 milligrams (mg) per day -- roughly the amount in two cups of coffee -- accelerated bone loss in women. However, the study reveals an important qualifier: The women's average calcium intake was 725mg per day, 475mg short of the Daily Recommended Intake.

"Caffeine can act as a calcium thief, but the real risk for osteoporosis is chronic low calcium," Coghlin-Dickson says.

It's well known that caffeine -- a stimulant -- can improve focus and concentration. Recent research also has linked caffeine to a reduced risk of Parkinson's disease. When scientists at Harvard University tracked rates of Parkinson's in more than 135,000 men and women for 12 years, they found that men who consumed four to five cups of coffee daily and women who consumed one to three cups daily were half as likely to develop the disease as those who didn't consume coffee. CookingLight.com: Healthy chocolate?

Researchers aren't yet sure why coffee has a protective effect but suggest the benefit could be linked to caffeine's ability to accelerate neurotransmissions in the brain.

Coffee's connection to diabetes prevention appears clearer. In a 10-year trial of  88,000 women, researchers from the Harvard School of Public Health in Boston, Massachusetts found that women who drank two or more cups of coffee per day were 47 percent less likely to develop type 2 diabetes, the adult-onset variety of the disease. In this study, the benefits of the brew weren't directly associated with caffeine; decaffeinated coffee provided similar results. More likely, chlorogenic acid, an antioxidant abundant in coffee, is responsible for the effect, says Frank Hu, M.D., Ph.D., lead author of the study and associate professor of nutrition and epidemiology.

What you should do: "Considering all of the evidence we've accumulated in the last 10 years, coffee is more healthful than harmful," Hu says. Like all things, caffeine -- and coffee --are probably best in moderation; have one cup, maybe two per day. You may also benefit from the brew's antioxidants; coffee is the top source of antioxidants in an American diet.

Omega-3s

The good news: Eating fish rich in omega-3s may improve your heart health.

The potential risk: Some types of fish contain high levels of mercury, a toxin.

What the research says: In 2004 the Food and Drug Administration and the Environmental Protection Agency issued an advisory recommending that pregnant or nursing women and young children avoid intake of high-mercury fish species, such as swordfish, king mackerel, tilefish, and shark because mercury can cause developmental defects in children. The threat is real, but the response isn't. Two-thirds of Americans believe the risk applies to everyone, not just expectant mothers and young children, according to a survey by the Center for Food, Nutrition, and Agriculture Policy.

"People think, 'If it's not good for babies, then it's probably not good for me,' " says Joshua Cohen, Ph.D., a lecturer at Tufts University School of Medicine in Boston. "But men and postmenopausal women should focus on the fact that eating fish can help reduce their risk of stroke and heart attack." CookingLight.com: Clearly healthy oils

When Cohen correlated data about fish consumption to annual rates of heart disease in a report published last year in the American Journal of Preventive Medicine, he determined that if all American adults -- including women of childbearing age -- consumed 8 ounces of a low-mercury fish each week, the annual number of coronary deaths in the United States would drop by 20,000. Omega-3 fats, which are provided by certain fish, help make "bad" LDL cholesterol less likely to stick to artery walls and may relieve arterial inflammation.

What you should do: If you're not a woman of childbearing age, consume two 6-ounce servings of fatty fish per week. "To sacrifice the benefits for a risk that doesn't pertain to you is cheating yourself," Cohen says. Stick with species that are low in mercury but high in omega-3s -- salmon, canned light tuna, pollock, flounder, sole, herring, shrimp, and sardines. E-mail to a friend

For more tips on making healthy taste great, try Cooking Light - CLICK HERE

Copyright 2009 Cooking Light magazine. All rights reserved.

@highlight

The most powerful source of vitamin D is the sun

@highlight

Recent research has linked caffeine to a reduced risk of Parkinson's disease

@highlight

For most, benefits of eating fatty fish outweigh mercury risks