(CNN) -- On a June day in 2009, a 39-year-old man named Ken Milles lay on an exam table at Cedars-Sinai Medical Center in Los Angeles. A month earlier, he'd suffered a massive heart attack that destroyed nearly a third of his heart.

"The most difficult part was the uncertainty," he recalls. "Your heart is 30% damaged, and they tell you this could affect you the rest of your life." He was about to receive an infusion of stem cells, grown from cells taken from his own heart a few weeks earlier. No one had ever tried this before.

About three weeks later, in Kentucky, a patient named Mike Jones underwent a similar procedure at the University of Louisville's Jewish Hospital. Jones suffered from advanced heart failure, the result of a heart attack years earlier. Like Milles, he received an infusion of stem cells, grown from his own heart tissue.

"Once you reach this stage of heart disease, you don't get better," says Dr. Robert Bolli, who oversaw Jones' procedure, explaining what doctors have always believed and taught. "You can go down slowly, or go down quickly, but you're going to go down."

Conventional wisdom took a hit Monday, as Bolli's group and a team from Cedars-Sinai each reported that stem cell therapies were able to reverse heart damage, without dangerous side effects, at least in a small group of patients.

In Bolli's study, published in The Lancet, 16 patients with severe heart failure received a purified batch of cardiac stem cells. Within a year, their heart function markedly improved. The heart's pumping ability can be quantified through the "Left Ventricle Ejection Fraction," a measure of how much blood the heart pumps with each contraction. A patient with an LVEF of less than 40% is considered to suffer severe heart failure. When the study began, Bolli's patients had an average LVEF of 30.3%. Four months after receiving stem cells, it was 38.5%. Among seven patients who were followed for a full year, it improved to an astounding 42.5%. A control group of seven patients, given nothing but standard maintenance medications, showed no improvement at all.

"We were surprised by the magnitude of improvement," says Bolli, who says traditional therapies, such as placing a stent to physically widen the patient's artery, typically make a smaller difference. Prior to treatment, Mike Jones couldn't walk to the restroom without stopping for breath, says Bolli. "Now he can drive a tractor on his farm, even play basketball with his grandchildren. His life was transformed."

At Cedars-Sinai, 17 patients, including Milles, were given stem cells approximately six weeks after suffering a moderate to major heart attack. All had lost enough tissue to put them "at big risk" of future heart failure, according to Dr. Eduardo Marban, the director of the Cedars-Sinai Heart Institute, who developed the stem cell procedure used there.

Cedars-Sinai: Helping the heart heal itself

The results were striking. Not only did scar tissue retreat -- shrinking 40% in Ken Milles, and between 30% and 47% in other test subjects -- but the patients actually generated new heart tissue. On average, the stem cell recipients grew the equivalent of 600 million new heart cells, according to Marban, who used MRI imaging to measure changes. By way of perspective, a major heart attack might kill off a billion cells.

"This is unprecedented, the first time anyone has grown living heart muscle," says Marban. "No one else has demonstrated that. It's very gratifying, especially when the conventional teaching has been that the damage is irreversible."

Perhaps even more important, no treated patient in either study suffered a significant health setback.

The twin findings are a boost to the notion that the heart contains the seeds of its own rebirth. For years, doctors believed that heart cells, once destroyed, were gone forever. But in a series of experiments, researchers including Bolli's collaborator, Dr. Piero Anversa, found that the heart contains a type of stem cell that can develop into either heart muscle or blood vessel components -- in essence, whatever the heart requires at a particular point in time. The problem for patients like Mike Jones or Ken Milles is that there simply aren't enough of these repair cells waiting around. The experimental treatments involve removing stem cells through a biopsy, and making millions of copies in a laboratory.

The Bolli/Anversa group and Marban's team both used cardiac stem cells, but Bolli and Anversa "purified" the CSCs, so that more than 90% of the infusion was actual stem cells. Marban, on the other hand, used a mixture of stem cells and other types of cells extracted from the patient's heart. "We've found that the mixture is more potent than any subtype we've been able to isolate," he says. He says the additional cells may help by providing a supportive environment for the stem cells to multiply.

Other scientists, including Dr. Douglas Losordo, have produced improvements in cardiac patients using stem cells derived from bone marrow. "The body contains cells that seem to be pre-programmed for repair," explains Losordo. "The consistent thing about all these approaches is that they're leveraging what seems to be the body's own repair mechanism."

Losordo praised the Lancet paper, and recalls the skepticism that met Anversa's initial claims, a decade ago, that there were stem cells in the adult heart. "Some scientists are always resistant to that type of novelty. You know the saying: First they ignore you, then they attack you and finally they imitate you."

Denis Buxton, who oversees stem cell research at the National Heart, Lung and Blood Institute at the National Institutes of Health, calls the new studies "a paradigm shift, harnessing the heart's own regenerative processes." But he says he would like to see more head-to-head comparisons to determine which type of cells are most beneficial.

Questions also remain about timing. Patients who suffer large heart attacks are prone to future damage, in part because the weakened heart tries to compensate by dilating -- swelling -- and by changing shape. In a vicious circle, the changes make the heart a less efficient pump, which leads to more overcompensation, and so on, until the end result is heart failure. Marban's study aimed to treat patients before they could develop heart failure in the first place.

In a third study released Monday, researchers treated patients with severe heart failure with stem cells derived from bone marrow. In a group of 60 patients, those receiving the treatment had fewer heart problems over the course of a year, as well as improved heart function.

A fourth study also used cells derived from bone marrow, but injected them into patients two to three weeks after a heart attack. Previous studies, with the cells given just days afterward, found a modest improvement in heart function. But Monday, the lead researcher, Dr. Dan Simon of UH Case Medical Center, reported that with the three-week delay, patients did not see the same benefit.

With other methods, there may be a larger window of opportunity. At least in initial studies, Losordo's bone marrow treatments helped some patients with long-standing heart problems. Bolli's Lancet paper suggests that CSCs, too, might help patients with advanced disease. "These patients had had heart failure for several years. They were a wreck!" says Bolli. "But we found their stem cells were still very competent." By that, he means the cells were still capable of multiplying and of turning into useful muscle and blood vessel walls.

Marban has an open mind on the timing issue. In fact, one patient from his control group e-mailed after the study was complete, saying he felt terrible and pleading for an infusion of stem cells. At Marban's request, the FDA granted special approval to treat him. "He had a very nice response. That was 14 months after his heart attack. Of course that's just one person, and we need bigger studies," says Marban.

For Ken Milles, the procedure itself wasn't painful, but it was unsettling. The biopsy to harvest the stem cells felt "weird," he recalls, as he felt the doctor poking around inside his heart. The infusion, a few weeks later, was harder. The procedure -- basically the same as an angioplasty -- involved stopping blood flow through the damaged artery for three minutes, while the stem cells were infused. "It felt exacfly like I was having a heart attack again," Milles remembers.

Milles had spent the first weeks after his heart attack just lying in bed re-watching his "Sopranos" DVDs, but within a week of the stem cell infusion, he says, "I was reinvigorated." Today he's back at work full time, as an accounting manager at a construction company. He's cut out fast food and shed 50 pounds. His wife and two teenage sons are thrilled.

Denis Buxton says the new papers could prove a milestone. "We don't have anything else to actually regenerate the heart. These stem cell therapies have the possibility of actually reversing damage."

Bolli says he'll have to temper his enthusiasm until he can duplicate the results in larger studies, definitive enough to get stem cell therapy approved as a standard treatment. "If a phase 3 study confirmed this, it would be the biggest advance in cardiology in my lifetime. We would possibly be curing heart failure. It would be a revolution."

Miriam Falco contributed to this story.

@highlight

In a study by Dr. Robert Bolli, 16 patients with heart failure received stem cell therapy

@highlight

Within a year, the heart function of the patients in the study markedly improved

@highlight

"We were surprised by the magnitude of improvement," says Bolli

@highlight

"We would possibly be curing heart failure. It would be a revolution," says Bolli