New York (CNN) -- Like most people, I'd given some thought to what meat actually is, but until I became a father and faced the prospect of having to make food choices on someone else's behalf, there was no urgency to get to the bottom of things.

I'm a novelist and never had it in mind to write nonfiction. Frankly, I doubt I'll ever do it again. But the subject of animal agriculture, at this moment, is something no one should ignore. As a writer, putting words on the page is how I pay attention.

If the way we raise animals for food isn't the most important problem in the world right now, it's arguably the No. 1 cause of global warming: The United Nations reports the livestock business generates more greenhouse gas emissions than all forms of transportation combined.

It's the No. 1 cause of animal suffering, a decisive factor in the creation of zoonotic diseases like bird and swine flu, and the list goes on. It is the problem with the most deafening silence surrounding it.

Even the most political people, the most thoughtful and engaged, tend not to "go there." And for good reason. Going there can be extremely uncomfortable. Food is not just what we put in our mouths to fill up; it is culture and identity. Reason plays some role in our decisions about food, but it's rarely driving the car.

We need a better way to talk about eating animals, a way that doesn't ignore or even just shruggingly accept things like habits, cravings, family and history but rather incorporates them into the conversation. The more they are allowed in, the more able we will be to follow our best instincts. And although there are many respectable ways to think about meat, there is not a person on Earth whose best instincts would lead him or her to factory farming.

My book, "Eating Animals," addresses factory farming from numerous perspectives: animal welfare, the environment, the price paid by rural communities, the economic costs. In two essays, I will share some of what I've learned about how the way we raise animals for food affects human health.

What we eat and what we are

Why aren't more people aware of, and angry about, the rates of avoidable food-borne illness? Perhaps it doesn't seem obvious that something is amiss simply because anything that happens all the time -- like meat, especially poultry, becoming infected by pathogens -- tends to fade into the background.

Whatever the case, if you know what to look for, the pathogen problem comes into terrifying focus. For example, the next time a friend has a sudden "flu" -- what folks sometimes misdescribe as "the stomach flu" -- ask a few questions. Was your friend's illness one of those "24-hour flus" that come and go quickly: retch or crap, then relief? The diagnosis isn't quite so simple, but if the answer to this question is yes, your friend probably didn't have the flu at all.

He or she was probably suffering from one of the 76 million cases of food-borne illness the Centers for Disease Control and Prevention has estimated happen in America each year. Your friend didn't "catch a bug" so much as eat a bug. And in all likelihood, that bug was created by factory farming.

Beyond the sheer number of illnesses linked to factory farming, we know that factory farms are contributing to the growth of antimicrobial-resistant pathogens simply because these farms consume so many antimicrobials.

We have to go to a doctor to obtain antibiotics and other antimicrobials as a public-health measure to limit the number of such drugs being taken by humans. We accept this inconvenience because of its medical importance. Microbes eventually adapt to antimicrobials, and we want to make sure it is the truly sick who benefit from the finite number of uses any antimicrobial will have before the microbes learn how to survive it.

On a typical factory farm, drugs are fed to animals with every meal. In poultry factory farms, they almost have to be. It's a perfect storm: The animals have been bred to such extremes that sickness is inevitable, and the living conditions promote illness.

Industry saw this problem from the beginning, but rather than accept less-productive animals, it compensated for the animals' compromised immunity with drugs. As a result, farmed animals are fed antibiotics nontherapeutically: that is, before they get sick.

In the United States, about 3 million pounds of antibiotics are given to humans each year, but a whopping 17.8 million pounds are fed to livestock -- at least, that is what the industry claims.

The Union of Concerned Scientists estimated that the industry underreported its antibiotic use by at least 40 percent.

The group calculated that 24.6 million pounds of antibiotics were fed to chickens, pigs and other farmed animals, counting only nontherapeutic uses. And that was in 2001. In other words, for every dose of antibiotics taken by a sick human, eight doses are given to a "healthy" animal.

The implications for creating drug-resistant pathogens are quite straightforward. Study after study has shown that antimicrobial resistance follows quickly on the heels of the introduction of new drugs on factory farms.

For example, in 1995, when the Food and Drug Administration approved fluoroquinolones -- such as Cipro -- for use in chickens against the protest of the Centers for Disease Control, the percentage of bacteria resistant to this powerful new class of antibiotics rose from almost zero to 18 percent by 2002.

A broader study in the  New England Journal of Medicine showed an eightfold increase in antimicrobial resistance from 1992 to 1997 and linked this increase to the use of antimicrobials in farmed chickens. As far back as the late 1960s, scientists have warned against the nontherapeutic use of antibiotics in farmed-animal feed.

Today, institutions as diverse as the American Medical Association; the Centers for Disease Control; the Institute of Medicine, a division of the National Academy of Sciences; and the World Health Organization have linked nontherapeutic antibiotic use on factory farms with increased antimicrobial resistance and called for a ban.

Still, the factory farm industry has effectively opposed such a ban in the United States. And, unsurprisingly, the limited bans in other countries are only a limited solution.

There is a glaring reason that the necessary total ban on nontherapeutic use of antibiotics hasn't happened: The factory farm industry, allied with the pharmaceutical industry, has more power than public-health professionals.

What is the source of the industry's immense power? We give it to them. We have chosen, unwittingly, to fund this industry on a massive scale by eating factory-farmed animal products. And we do so daily.

The same conditions that lead at least 76 million Americans to become ill from their food annually and that promote antimicrobial resistance also contribute to the risk of a pandemic.

At a remarkable 2004 conference, the Food and Agriculture Organization of the United Nations, the World Health Organization and the World Organization for Animal Health (OIE) put their tremendous resources together to evaluate the available information on "emerging zoonotic diseases" or those spread by humans-to- animals and animals-to-humans.

At the time of the conference, H5N1 and SARS topped the list of feared emerging zoonotic diseases. Today, the H1N1 swine flu would be the pathogen enemy No. 1.

The scientists distinguished between "primary risk factors" for zoonotic diseases and mere "amplification risk factors," which affect only the rate at which a disease spreads. Their examples of primary risk factors were "change to an agricultural production system or consumption patterns." What particular agricultural and consumer changes did they have in mind?

First in a list of four main risk factors was "increasing demand for animal protein," which is a way of saying that demand for meat, eggs, and dairy is a "primary factor" influencing emerging zoonotic diseases. This demand for animal products, the report continues, leads to "changes in farming practices." Lest we have any confusion about the "changes" that are relevant, poultry factory farms are singled out.

Similar conclusions were reached by the Council for Agricultural Science and Technology, which brought together industry experts and experts from the WHO, OIE and USDA. Their 2005 report argued that a major impact of factory farming is "the rapid selection and amplification of pathogens that arise from a virulent ancestor (frequently by subtle mutation), thus there is increasing risk for disease entrance and/or dissemination."

Breeding genetically uniform and sickness-prone birds in the overcrowded, stressful, feces-infested and artificially lit conditions of factory farms promotes the growth and mutation of pathogens. The "cost of increased efficiency," the report concludes, is increased global risk for diseases. Our choice is simple: cheap chicken or our health.

Today, the factory farm-pandemic link couldn't be more lucid. The primary ancestor of the recent H1N1 swine flu outbreak originated at a hog factory farm in America's most hog-factory-rich state, North Carolina, and then quickly spread throughout the Americas.

It was in these factory farms that scientists saw, for the first time, viruses that combined genetic material from bird, pig and human viruses. Scientists at Columbia and Princeton Universities have actually been able to trace six of the eight genetic segments of the most feared virus in the world directly to U.S. factory farms.

Perhaps in the back of our minds we already understand, without all the science, that something terribly wrong is happening. We know that it cannot possibly be healthy to raise such grotesque animals in such grossly unnatural conditions. We know that if someone offers to show us a film on how our meat is produced, it will be a horror film.

We perhaps know more than we care to admit, keeping it down in the dark places of our memory -- disavowed. When we eat factory-farmed meat, we live on tortured flesh. Increasingly, those sick animals are making us sick.

The opinions expressed in this commentary are solely those of Jonathan Safran Foer.

@highlight

Jonathan Safran Foer: Inhumane way we raise animals for slaughter poisons us all

@highlight

Foer: Factory farming tied to global warming, swine and bird flu, other illnesses

@highlight

He says animals loaded with antibiotics, live in gruesome conditions

@highlight

System driven by food and pharmaceutical industries; Foer asks: Why no outcry?